@@ -56,7 +56,7 @@ from torch.utils.data.distributed import DistributedSampler
 from transformers import AutoModelForCausalLM, AutoTokenizer
 
 
-ignore_sanity_checks = int(os.environ.get("IGNORE_SANITY", 0)) == 1
+ignore_sanity_checks = int(os.environ.get("IGNORE_SANITY", "0")) == 1
 # torch.use_deterministic_algorithms(True)
 torch.backends.cudnn.deterministic = True
 
@@ -74,9 +74,9 @@ logger = logging.getLogger(__name__)
 
 
 def main():
-    tp_size = int(os.environ.get("TP_SIZE", 1))
-    dp_size = int(os.environ.get("DP_SIZE", 4))
-    cp_size = int(os.environ.get("CP_SIZE", 1))  # Add CP size configuration
+    tp_size = int(os.environ.get("TP_SIZE", "1"))
+    dp_size = int(os.environ.get("DP_SIZE", "4"))
+    cp_size = int(os.environ.get("CP_SIZE", "1"))  # Add CP size configuration
     sdpa_backend = SDPBackend.FLASH_ATTENTION  # For CP
     # sdpa_backend = SDPBackend.MATH # For CP
     global_batch_size = 8  # Desired global batch size
@@ -165,7 +165,7 @@ def main():
         model_name,
         device_mesh=tp_mesh if dist.is_initialized() else None,
         tp_plan="auto",
-        torch_dtype=torch.bfloat16,
+        dtype=torch.bfloat16,
     )
     logger.info(f"Model loaded onto device mesh: {tp_mesh}")
 
@@ -469,7 +469,7 @@ def main():
         new_model = AutoModelForCausalLM.from_pretrained(
             model_name,
             device_mesh=tp_mesh,
-            torch_dtype=torch.bfloat16,  # Use same dtype
+            dtype=torch.bfloat16,  # Use same dtype
         )
         new_optimizer = optim.AdamW(new_model.parameters(), lr=LR)
 
