@@ -446,7 +446,7 @@ def quantize_with_higgs(weight, bits: int = 4, p: int = 2, group_size: int = 256
 
     device = weight.device
     dtype = weight.dtype
-    weight = weight.clone().float()
+    weight = weight.to(copy=True, dtype=torch.float32)
     # Pad to Hadamard transform size
     weight = pad_to_block(weight, [1], hadamard_size)
 
@@ -554,11 +554,12 @@ def replace_with_higgs_linear(
     quantization_config=None,
     current_key_name=None,
     has_been_replaced=False,
+    modules_to_not_convert=None,
 ):
     """
     Public method that recursively replaces the Linear layers of the given model with HIGGS quantized layers.
     `accelerate` is needed to use this method. Returns the converted model and a boolean that indicates if the
-    conversion has been successfull or not.
+    conversion has been successful or not.
 
     Args:
         model (`torch.nn.Module`):
@@ -582,7 +583,7 @@ def replace_with_higgs_linear(
         if isinstance(module, nn.Linear):
             # Check if the current key is not in the `quantization_config.modules_to_not_convert`
             current_key_name_str = ".".join(current_key_name)
-            if not any(current_key_name_str.endswith(key) for key in quantization_config.modules_to_not_convert):
+            if not any(current_key_name_str.endswith(key) for key in modules_to_not_convert):
                 with init_empty_weights():
                     in_features = module.in_features
                     out_features = module.out_features
@@ -607,6 +608,7 @@ def replace_with_higgs_linear(
                 quantization_config=quantization_config,
                 current_key_name=current_key_name,
                 has_been_replaced=has_been_replaced,
+                modules_to_not_convert=modules_to_not_convert,
             )
         # Remove the last key for recursion
         current_key_name.pop(-1)
