@@ -60,7 +60,7 @@ def initialize_tensor_parallelism(tp_plan, tp_size=None):
 
             backend_map = {"cuda": "nccl", "cpu": "gloo", "xpu": "xccl", "hpu": "hccl"}
             backend = backend_map.get(device_type)
-            if device_type == "cpu" and int(os.environ.get("CCL_WORKER_COUNT", 0)):
+            if device_type == "cpu" and int(os.environ.get("CCL_WORKER_COUNT", "0")):
                 backend = "ccl"
             if device_type == "xpu" and not is_torch_greater_or_equal("2.8", accept_dev=True):
                 backend = "ccl"
@@ -138,7 +138,7 @@ def _get_parameter_tp_plan(parameter_name: str, tp_plan: dict[str, str], is_weig
     return None
 
 
-str_to_torch_dtype = {
+str_to_dtype = {
     "BOOL": torch.bool,
     "U8": torch.uint8,
     "I8": torch.int8,
@@ -218,7 +218,7 @@ def get_packed_weights(param, empty_param, device_mesh, rank, dim):
     if casted:
         return tensor
     else:
-        return tensor.to(str_to_torch_dtype[slice_dtype])
+        return tensor.to(str_to_dtype[slice_dtype])
 
 
 def repack_weights(
@@ -677,7 +677,7 @@ class RowwiseParallel(TensorParallelLayer):
             outputs = outputs.redistribute(placements=output_layouts, async_op=True)
         outputs = outputs.to_local()  # otherwise the `+=` op will gather
         if hasattr(mod, "_bias"):
-            outputs += mod._bias
+            outputs = outputs + mod._bias
         # back to local tensor if use_local_output is True
         return outputs
 
@@ -1013,8 +1013,7 @@ def shard_and_distribute_module(
 
     """
     param_name, param_type = parameter_name.rsplit(".", 1) if "." in parameter_name else parameter_name
-    tp_plan = model._tp_plan or {}
-    tp_plan.update(getattr(type(model), "_tp_plan", None) or {})
+    tp_plan = model.tp_plan or {}
     module_to_tp = model.get_submodule(param_name)  # TODO: can i loop over modules?
     rank = int(rank)
     current_shard_plan = _get_parameter_tp_plan(parameter_name, tp_plan)
@@ -1079,42 +1078,26 @@ def verify_tp_plan(expected_keys: list[str], tp_plan: dict[str, str] | None):
 
 
 def distribute_model(model, distributed_config, device_mesh, tp_size):
-    _plan = "_tp_plan"
-    tp_plan = (getattr(model, "_tp_plan", None) or {}).copy()
-    model._tp_plan = getattr(model.config, "base_model_tp_plan").copy()
-    model._tp_plan.update(tp_plan)
     model._tp_size = tp_size
     model._device_mesh = device_mesh
     if distributed_config is not None:
         if isinstance(distributed_config, dict):
             distributed_config = DistributedConfig.from_dict(distributed_config)
-        if distributed_config.enable_expert_parallel:
-            _plan = "_ep_plan"
-            model._tp_plan = getattr(model.config, "base_model_ep_plan", model._tp_plan).copy()
-
-    # now fetch my childrens
-    for name, module in model.named_children():
-        if plan := getattr(module, _plan, getattr(module, "tp_plan", None)):
-            model._tp_plan.update({f"{name}.{k}": v for k, v in plan.copy().items()})
-        if hasattr(module, "config"):
-            plan = getattr(module.config, f"base_model{_plan}", {})
-            if plan == {}:
-                plan = getattr(module.config, "base_model_tp_plan", {})
-            model._tp_plan.update({f"{name}.{k}": v for k, v in plan.copy().items()})
-
-    if model._tp_plan is not None and is_torch_greater_or_equal("2.5") and _torch_distributed_available:
-        for v in model._tp_plan.values():
+        model.config.distributed_config = distributed_config
+    model_plan = model.tp_plan
+    if model_plan is not None and is_torch_greater_or_equal("2.5") and _torch_distributed_available:
+        for v in model_plan.values():
             if v not in ALL_PARALLEL_STYLES:
                 raise ValueError(f"Unsupported tensor parallel style {v}. Supported styles are {ALL_PARALLEL_STYLES}")
         for name, module in model.named_modules():
             if not getattr(module, "_is_hooked", False):
                 from transformers.integrations.tensor_parallel import add_tensor_parallel_hooks_to_module
 
-                plan = _get_parameter_tp_plan(parameter_name=name, tp_plan=model._tp_plan, is_weight=False)
+                plan = _get_parameter_tp_plan(parameter_name=name, tp_plan=model_plan, is_weight=False)
                 add_tensor_parallel_hooks_to_module(
                     model=model,
                     module=module,
-                    tp_plan=model._tp_plan,
+                    tp_plan=model_plan,
                     layer_name="",
                     current_module_plan=plan,
                     device_mesh=device_mesh,
