@@ -168,7 +168,7 @@ class BridgeTowerImageProcessor(BaseImageProcessor):
             the `do_pad` parameter in the `preprocess` method.
     """
 
-    model_input_names = ["pixel_values"]
+    model_input_names = ["pixel_values", "pixel_mask"]
 
     def __init__(
         self,
@@ -465,6 +465,7 @@ class BridgeTowerImageProcessor(BaseImageProcessor):
 
         size = size if size is not None else self.size
         size = get_size_dict(size, default_to_square=False)
+        images = self.fetch_images(images)
         images = make_flat_list_of_images(images)
 
         if not valid_images(images):
