@@ -1991,6 +1991,10 @@ class EsmFoldingTrunk(nn.Module):
 class EsmForProteinFolding(EsmPreTrainedModel):
     _no_split_modules = ["EsmFoldStructureModule", "EsmFoldTriangularSelfAttentionBlock"]
     _supports_flash_attn = False
+    _supports_sdpa = False
+    _supports_attention_backend = False
+
+    _can_record_outputs = None
 
     def __init__(self, config):
         super().__init__(config)
