@@ -19,7 +19,14 @@ from typing import Optional, Union
 import torch
 import torch.nn as nn
 
-from transformers.models.llava.modeling_llava import (
+from ...cache_utils import Cache
+from ...configuration_utils import PretrainedConfig
+from ...modeling_flash_attention_utils import FlashAttentionKwargs
+from ...modeling_utils import PreTrainedModel
+from ...processing_utils import Unpack
+from ...utils import auto_docstring, can_return_tuple, logging
+from ..auto import CONFIG_MAPPING, AutoConfig
+from ..llava.modeling_llava import (
     LlavaCausalLMOutputWithPast,
     LlavaForConditionalGeneration,
     LlavaModel,
@@ -27,7 +34,7 @@ from transformers.models.llava.modeling_llava import (
     LlavaPreTrainedModel,
     TransformersKwargs,
 )
-from transformers.models.sam.modeling_sam import (
+from ..sam.modeling_sam import (
     SamMLPBlock,
     SamPreTrainedModel,
     SamVisionAttention,
@@ -35,13 +42,6 @@ from transformers.models.sam.modeling_sam import (
     SamVisionLayer,
 )
 
-from ...cache_utils import Cache
-from ...configuration_utils import PretrainedConfig
-from ...modeling_flash_attention_utils import FlashAttentionKwargs
-from ...processing_utils import Unpack
-from ...utils import auto_docstring, can_return_tuple, logging
-from ..auto import CONFIG_MAPPING, AutoConfig
-
 
 logger = logging.get_logger(__name__)
 
@@ -240,7 +240,7 @@ class GotOcr2VisionAttention(SamVisionAttention):
 
 class GotOcr2VisionLayer(SamVisionLayer):
     def __init__(self, config, window_size):
-        super().__init__()
+        super().__init__(config, window_size)
         self.layer_norm1 = nn.LayerNorm(config.hidden_size, eps=config.layer_norm_eps)
         self.attn = GotOcr2VisionAttention(config, window_size)
         self.layer_norm2 = nn.LayerNorm(config.hidden_size, eps=config.layer_norm_eps)
@@ -291,7 +291,7 @@ class GotOcr2PreTrainedModel(LlavaPreTrainedModel):
     _supports_flex_attn = False
 
     def _init_weights(self, module):
-        LlavaPreTrainedModel._init_weights(module)
+        PreTrainedModel._init_weights(self, module)
         if isinstance(module, GotOcr2VisionAttention):
             if module.use_rel_pos:
                 module.rel_pos_h.data.zero_()
