@@ -66,6 +66,7 @@ if is_torch_available():
 
 if is_torchvision_v2_available():
     from torchvision.transforms.v2 import functional as F
+
 elif is_torchvision_available():
     from torchvision.transforms import functional as F
 
@@ -312,7 +313,7 @@ class MaskFormerImageProcessorFast(BaseImageProcessorFast):
     ) -> BatchFeature:
         """
         Preprocess image-like inputs.
-        To be overriden by subclasses when image-like inputs other than images should be processed.
+        To be overridden by subclasses when image-like inputs other than images should be processed.
         It can be used for segmentation maps, depth maps, etc.
         """
         # Prepare input images
@@ -370,7 +371,9 @@ class MaskFormerImageProcessorFast(BaseImageProcessorFast):
                         image=grouped_segmentation_maps[shape],
                         size=size,
                         size_divisor=size_divisor,
-                        interpolation=F.InterpolationMode.NEAREST_EXACT,
+                        interpolation=F.InterpolationMode.NEAREST_EXACT
+                        if is_torchvision_v2_available()
+                        else F.InterpolationMode.NEAREST,
                     )
             resized_images_grouped[shape] = stacked_images
             if segmentation_maps is not None:
