@@ -54,6 +54,7 @@ from ..utils import (
     is_torch_xpu_available,
     logging,
 )
+from ..utils.deprecation import deprecate_kwarg
 
 
 GenericTensor = Union[list["GenericTensor"], "torch.Tensor", "tf.Tensor"]
@@ -295,16 +296,16 @@ def infer_framework_load_model(
                 # Stop loading on the first successful load.
                 break
             except (OSError, ValueError, TypeError, RuntimeError):
-                # `from_pretrained` may raise a `TypeError` or `RuntimeError` when the requested `torch_dtype`
+                # `from_pretrained` may raise a `TypeError` or `RuntimeError` when the requested `dtype`
                 # is not supported on the execution device (e.g. bf16 on a consumer GPU). We capture those so
                 # we can transparently retry the load in float32 before surfacing an error to the user.
                 fallback_tried = False
-                if is_torch_available() and ("torch_dtype" in kwargs):
+                if is_torch_available() and ("dtype" in kwargs):
                     import torch  # local import to avoid unnecessarily importing torch for TF/JAX users
 
                     fallback_tried = True
                     fp32_kwargs = kwargs.copy()
-                    fp32_kwargs["torch_dtype"] = torch.float32
+                    fp32_kwargs["dtype"] = torch.float32
 
                     try:
                         model = model_class.from_pretrained(model, **fp32_kwargs)
@@ -449,7 +450,7 @@ def get_default_model_and_revision(
     else:
         # XXX This error message needs to be updated to be more generic if more tasks are going to become
         # parametrized
-        raise ValueError('The task defaults can\'t be correctly selected. You probably meant "translation_XX_to_YY"')
+        raise ValueError('The task defaults can\'t be correctly selected. You probably meant "translation_xx_to_yy"')
 
     if framework is None:
         framework = "pt"
@@ -858,7 +859,7 @@ def build_pipeline_init_args(
         device (`int`, *optional*, defaults to -1):
             Device ordinal for CPU/GPU supports. Setting this to -1 will leverage CPU, a positive will run the model on
             the associated CUDA device id. You can pass native `torch.device` or a `str` too
-        torch_dtype (`str` or `torch.dtype`, *optional*):
+        dtype (`str` or `torch.dtype`, *optional*):
             Sent directly as `model_kwargs` (just a simpler shortcut) to use the available precision for this model
             (`torch.float16`, `torch.bfloat16`, ... or `"auto"`)"""
     if supports_binary_output:
@@ -950,12 +951,12 @@ class Pipeline(_ScikitCompat, PushToHubMixin):
         modelcard: Optional[ModelCard] = None,
         framework: Optional[str] = None,
         task: str = "",
-        args_parser: ArgumentHandler = None,
         device: Union[int, "torch.device"] = None,
-        torch_dtype: Optional[Union[str, "torch.dtype"]] = None,
         binary_output: bool = False,
         **kwargs,
     ):
+        # We need to pop them for _sanitize_parameters call later
+        _, _, _ = kwargs.pop("args_parser", None), kwargs.pop("torch_dtype", None), kwargs.pop("dtype", None)
         if framework is None:
             framework, model = infer_framework_load_model(model, config=model.config)
         if framework in ("tf", "jax"):
@@ -1200,11 +1201,19 @@ class Pipeline(_ScikitCompat, PushToHubMixin):
         """
         return self(X)
 
+    @property
+    def dtype(self) -> Optional["torch.dtype"]:
+        """
+        Dtype of the model (if it's Pytorch model), `None` otherwise.
+        """
+        return getattr(self.model, "dtype", None)
+
     @property
     def torch_dtype(self) -> Optional["torch.dtype"]:
         """
         Torch dtype of the model (if it's Pytorch model), `None` otherwise.
         """
+        logger.warning_once("`torch_dtype` attribute is deprecated. Use `dtype` instead!")
         return getattr(self.model, "dtype", None)
 
     @contextmanager
@@ -1269,7 +1278,7 @@ class Pipeline(_ScikitCompat, PushToHubMixin):
         elif isinstance(inputs, list):
             return [self._ensure_tensor_on_device(item, device) for item in inputs]
         elif isinstance(inputs, tuple):
-            return tuple([self._ensure_tensor_on_device(item, device) for item in inputs])
+            return tuple(self._ensure_tensor_on_device(item, device) for item in inputs)
         elif isinstance(inputs, torch.Tensor):
             return inputs.to(device)
         else:
@@ -1541,6 +1550,7 @@ class PipelineRegistry:
             f"Unknown task {task}, available tasks are {self.get_supported_tasks() + ['translation_XX_to_YY']}"
         )
 
+    @deprecate_kwarg(old_name="tf_model", version="5.0.0")
     def register_pipeline(
         self,
         task: str,
