@@ -104,7 +104,7 @@ class Trie:
 
     def split(self, text: str) -> list[str]:
         """
-        Will look for the words added to the trie within `text`. Output is the original string splitted along the
+        Will look for the words added to the trie within `text`. Output is the original string split along the
         boundaries of the words found.
 
         This trie will match the longest possible word first !
@@ -877,9 +877,11 @@ class PreTrainedTokenizer(PreTrainedTokenizerBase):
 
         input_ids = []
         for ids_or_pair_ids in batch_text_or_text_pairs:
-            if not isinstance(ids_or_pair_ids, (list, tuple)):
-                ids, pair_ids = ids_or_pair_ids, None
-            elif is_split_into_words and not isinstance(ids_or_pair_ids[0], (list, tuple)):
+            if (
+                not isinstance(ids_or_pair_ids, (list, tuple))
+                or is_split_into_words
+                and not isinstance(ids_or_pair_ids[0], (list, tuple))
+            ):
                 ids, pair_ids = ids_or_pair_ids, None
             else:
                 ids, pair_ids = ids_or_pair_ids
