@@ -589,9 +589,9 @@ class DetrModelIntegrationTestsTimmBackbone(unittest.TestCase):
             {
                 (None, None):
                     [
-                        [0.0622, -0.5142, -0.4034],
-                        [-0.7628, -0.4935, -1.7153],
-                        [-0.4751, -0.6386, -0.7818],
+                        [0.0616, -0.5146, -0.4032],
+                        [-0.7629, -0.4934, -1.7153],
+                        [-0.4768, -0.6403, -0.7826],
                     ],
                 ("rocm", (9, 5)):
                     [
@@ -623,9 +623,9 @@ class DetrModelIntegrationTestsTimmBackbone(unittest.TestCase):
             {
                 (None, None):
                     [
-                        [-19.1211, -0.0881, -11.0188],
-                        [-17.3641, -1.8045, -14.0229],
-                        [-20.0415, -0.5833, -11.1005],
+                        [-19.1194, -0.0893, -11.0154],
+                        [-17.3640, -1.8035, -14.0219],
+                        [-20.0461, -0.5837, -11.1060],
                     ],
                 ("rocm", (9, 5)):
                     [
@@ -681,9 +681,9 @@ class DetrModelIntegrationTestsTimmBackbone(unittest.TestCase):
             {
                 (None, None):
                     [
-                        [-18.1523, -1.7592, -13.5019],
-                        [-16.8866, -1.4139, -14.1025],
-                        [-17.5735, -2.5090, -11.8666],
+                        [-18.1565, -1.7568, -13.5029],
+                        [-16.8888, -1.4138, -14.1028],
+                        [-17.5709, -2.5080, -11.8654],
                     ],
                 ("rocm", (9, 5)):
                     [
@@ -702,9 +702,9 @@ class DetrModelIntegrationTestsTimmBackbone(unittest.TestCase):
             {
                 (None, None):
                     [
-                        [0.5344, 0.1790, 0.9284],
-                        [0.4421, 0.0571, 0.0875],
-                        [0.6632, 0.6886, 0.1015]
+                        [0.5344, 0.1789, 0.9285],
+                        [0.4420, 0.0572, 0.0875],
+                        [0.6630, 0.6887, 0.1017],
                     ],
                 ("rocm", (9, 5)):
                     [
@@ -723,9 +723,9 @@ class DetrModelIntegrationTestsTimmBackbone(unittest.TestCase):
             {
                 (None, None):
                     [
-                        [-7.8408, -11.0104, -12.1279],
-                        [-12.0299, -16.6498, -17.9806],
-                        [-14.8995, -19.9940, -20.5646],
+                        [-7.7557, -10.8788, -11.9797],
+                        [-11.8880, -16.4328, -17.7450],
+                        [-14.7315, -19.7382, -20.3003],
                     ],
                 ("rocm", (9, 5)):
                     [
@@ -793,9 +793,9 @@ class DetrModelIntegrationTests(unittest.TestCase):
             {
                 (None, None):
                     [
-                        [0.0622, -0.5142, -0.4034],
-                        [-0.7628, -0.4935, -1.7153],
-                        [-0.4751, -0.6386, -0.7818],
+                        [0.0616, -0.5146, -0.4032],
+                        [-0.7629, -0.4934, -1.7153],
+                        [-0.4768, -0.6403, -0.7826],
                     ],
                 ("rocm", (9, 5)):
                     [
