@@ -13,6 +13,7 @@
 # limitations under the License.
 """Testing suite for the PyTorch GptOss model."""
 
+import difflib
 import inspect
 import json
 import os
@@ -21,7 +22,6 @@ import tempfile
 import unittest
 from pathlib import Path
 
-import pytest
 from parameterized import parameterized
 
 from transformers import (
@@ -48,6 +48,8 @@ if is_torch_available():
 
     from transformers import (
         GptOssForCausalLM,
+        GptOssForSequenceClassification,
+        GptOssForTokenClassification,
         GptOssModel,
     )
 
@@ -59,11 +61,15 @@ class GptOssModelTester(CausalLMModelTester):
         config_class = GptOssConfig
         base_model_class = GptOssModel
         causal_lm_class = GptOssForCausalLM
+        sequence_class = GptOssForSequenceClassification
+        token_class = GptOssForTokenClassification
 
     pipeline_model_mapping = (
         {
             "feature-extraction": GptOssModel,
+            "text-classification": GptOssForSequenceClassification,
             "text-generation": GptOssForCausalLM,
+            "token-classification": GptOssForTokenClassification,
         }
         if is_torch_available()
         else {}
@@ -72,11 +78,17 @@ class GptOssModelTester(CausalLMModelTester):
 
 @require_torch
 class GptOssModelTest(CausalLMModelTest, unittest.TestCase):
-    all_model_classes = (GptOssModel, GptOssForCausalLM) if is_torch_available() else ()
+    all_model_classes = (
+        (GptOssModel, GptOssForCausalLM, GptOssForSequenceClassification, GptOssForTokenClassification)
+        if is_torch_available()
+        else ()
+    )
     pipeline_model_mapping = (
         {
             "feature-extraction": GptOssModel,
+            "text-classification": GptOssForSequenceClassification,
             "text-generation": GptOssForCausalLM,
+            "token-classification": GptOssForTokenClassification,
         }
         if is_torch_available()
         else {}
@@ -92,10 +104,6 @@ class GptOssModelTest(CausalLMModelTest, unittest.TestCase):
         self.model_tester = GptOssModelTester(self)
         self.config_tester = ConfigTester(self, config_class=GptOssConfig, hidden_size=37)
 
-    @unittest.skip("Failing because of unique cache (HybridCache)")
-    def test_model_outputs_equivalence(self, **kwargs):
-        pass
-
     @unittest.skip("GptOss's forcefully disables sdpa due to Sink")
     def test_sdpa_can_dispatch_non_composite_models(self):
         pass
@@ -104,64 +112,6 @@ class GptOssModelTest(CausalLMModelTest, unittest.TestCase):
     def test_eager_matches_sdpa_generate(self):
         pass
 
-    @parameterized.expand([("random",), ("same",)])
-    @pytest.mark.generate
-    @unittest.skip("GptOss has HybridCache which is not compatible with assisted decoding")
-    def test_assisted_decoding_matches_greedy_search(self, assistant_type):
-        pass
-
-    @unittest.skip("GptOss has HybridCache which is not compatible with assisted decoding")
-    def test_prompt_lookup_decoding_matches_greedy_search(self, assistant_type):
-        pass
-
-    @pytest.mark.generate
-    @unittest.skip("GptOss has HybridCache which is not compatible with assisted decoding")
-    def test_assisted_decoding_sample(self):
-        pass
-
-    @unittest.skip("GptOss has HybridCache which is not compatible with dola decoding")
-    def test_dola_decoding_sample(self):
-        pass
-
-    @unittest.skip("GptOss has HybridCache and doesn't support continue from past kv")
-    def test_generate_continue_from_past_key_values(self):
-        pass
-
-    @unittest.skip("GptOss has HybridCache and doesn't support contrastive generation")
-    def test_contrastive_generate(self):
-        pass
-
-    @unittest.skip("GptOss has HybridCache and doesn't support contrastive generation")
-    def test_contrastive_generate_dict_outputs_use_cache(self):
-        pass
-
-    @unittest.skip("GptOss has HybridCache and doesn't support contrastive generation")
-    def test_contrastive_generate_low_memory(self):
-        pass
-
-    @unittest.skip("GptOss has HybridCache and doesn't support StaticCache. Though it could, it shouldn't support.")
-    def test_generate_with_static_cache(self):
-        pass
-
-    @unittest.skip("GptOss has HybridCache and doesn't support StaticCache. Though it could, it shouldn't support.")
-    def test_generate_from_inputs_embeds_with_static_cache(self):
-        pass
-
-    @unittest.skip("GptOss has HybridCache and doesn't support StaticCache. Though it could, it shouldn't support.")
-    def test_generate_continue_from_inputs_embeds(self):
-        pass
-
-    @unittest.skip(
-        reason="HybridCache can't be gathered because it is not iterable. Adding a simple iter and dumping `distributed_iterator`"
-        " as in Dynamic Cache doesn't work. NOTE: @gante all cache objects would need better compatibility with multi gpu setting"
-    )
-    def test_multi_gpu_data_parallel_forward(self):
-        pass
-
-    @unittest.skip("GptOss has HybridCache which auto-compiles. Compile and FA2 don't work together.")
-    def test_eager_matches_fa2_generate(self):
-        pass
-
     @unittest.skip("GptOss eager/FA2 attention outputs are expected to be different")
     def test_flash_attn_2_equivalence(self):
         pass
@@ -174,6 +124,10 @@ class GptOssModelTest(CausalLMModelTest, unittest.TestCase):
     def test_flex_attention_with_grads(self):
         pass
 
+    @unittest.skipIf(torch_device == "cpu", "GptOss does not support flex officially")
+    def test_generate_compile_model_forward_fullgraph(self):
+        return super().test_generate_compile_model_forward_fullgraph()
+
 
 RESULTS_PATH = Path(__file__).parent.parent.parent / "fixtures/gpt_oss/integration_tests.json"
 
@@ -188,6 +142,10 @@ def distributed_worker(quantized, model_size, kernels, attn_impl, mode):
     from transformers import AutoModelForCausalLM, AutoTokenizer
     from transformers.testing_utils import torch_device
 
+    def generate_config_key(quantized, model, kernels, attn_impl, mode):
+        """Generate a key for the restructured integration test results."""
+        return f"quantized={str(quantized).lower()}|model={model}|kernels={str(kernels).lower()}|attn_impl={attn_impl}|mode={mode}"
+
     input_text = [
         "Roses are red, violets",
         "How are you? Tell me the name of the president of",
@@ -198,10 +156,10 @@ def distributed_worker(quantized, model_size, kernels, attn_impl, mode):
     kernels = kernels.lower() == "true"
 
     # Distributed model loading
-    model_id = f"/fsx/vb/new-oai/gpt-oss-{model_size}-trfs"
+    model_id = f"openai/gpt-oss-{model_size}"
     model = AutoModelForCausalLM.from_pretrained(
         model_id,
-        torch_dtype="auto",
+        dtype="auto",
         tp_plan="auto",  # distributed inference
         use_kernels=kernels,
     ).to(torch_device)
@@ -213,26 +171,54 @@ def distributed_worker(quantized, model_size, kernels, attn_impl, mode):
     output = model.generate(**inputs, max_new_tokens=20, do_sample=False)
     output_texts = tokenizer.batch_decode(output, skip_special_tokens=False)
 
-    # Only rank 0 writes results
+    # Only rank 0 writes results and validates against expected outputs
     if int(os.environ.get("RANK", "0")) == 0:
-        result_entry = {
-            "quantized": quantized,
-            "model": model_size,
-            "kernels": kernels,
-            "attn_impl": attn_impl,
-            "mode": mode,
-            "outputs": output_texts,
-        }
+        # Generate key to look up expected outputs
+        key = generate_config_key(quantized, model_size, kernels, attn_impl, mode)
 
+        # Load expected outputs from restructured JSON
         if os.path.exists(RESULTS_PATH):
             with open(RESULTS_PATH, "r") as f:
-                results = json.load(f)
-        else:
-            results = []
-        results.append(result_entry)
+                expected_results = json.load(f)
 
-        with open(RESULTS_PATH, "w") as f:
-            json.dump(results, f, indent=2)
+            # Check if we have expected results for this configuration
+            if key in expected_results:
+                expected_outputs = expected_results[key]
+
+                # Compare actual outputs with expected outputs
+                assert len(output_texts) == len(expected_outputs), f"Output length mismatch for {key}"
+
+                for i, (actual, expected) in enumerate(zip(output_texts, expected_outputs)):
+                    actual_stripped = actual.strip()
+                    expected_stripped = expected.strip()
+
+                    # Make lengths match by taking minimum length to be resilient to generation differences
+                    min_length = min(len(actual_stripped), len(expected_stripped))
+                    actual_truncated = actual_stripped[:min_length]
+                    expected_truncated = expected_stripped[:min_length]
+
+                    if actual_truncated != expected_truncated:
+                        diff = "\n".join(
+                            difflib.unified_diff(
+                                expected_truncated.splitlines(keepends=True),
+                                actual_truncated.splitlines(keepends=True),
+                                fromfile=f"expected[{i}]",
+                                tofile=f"actual[{i}]",
+                                lineterm="",
+                            )
+                        )
+                        raise AssertionError(
+                            f"Output mismatch at index {i} for {key}:\n"
+                            f"Expected: '{expected_stripped}'\n"
+                            f"Actual:   '{actual_stripped}'\n"
+                            f"Diff (truncated to min length {min_length}):\n{diff}"
+                        )
+
+                print(f"✓ Outputs match expected results for {key}")
+            else:
+                print(f"Warning: No expected results found for configuration: {key}")
+        else:
+            print(f"Warning: Results file {RESULTS_PATH} not found")
 
 
 @slow
@@ -243,6 +229,11 @@ class GptOssIntegrationTest(unittest.TestCase):
         "How are you? Tell me the name of the president of",
     ]
 
+    @staticmethod
+    def generate_config_key(quantized, model, kernels, attn_impl, mode):
+        """Generate a key for the restructured integration test results."""
+        return f"quantized={str(quantized).lower()}|model={model}|kernels={str(kernels).lower()}|attn_impl={attn_impl}|mode={mode}"
+
     def setUp(self):
         cleanup(torch_device, gc_collect=True)
 
@@ -256,7 +247,7 @@ class GptOssIntegrationTest(unittest.TestCase):
     def load_and_forward(model_id, attn_implementation, input_text, **pretrained_kwargs):
         model = AutoModelForCausalLM.from_pretrained(
             model_id,
-            torch_dtype=torch.bfloat16,
+            dtype=torch.bfloat16,
             device_map="auto",
             attn_implementation=attn_implementation,
             **pretrained_kwargs,
@@ -265,7 +256,7 @@ class GptOssIntegrationTest(unittest.TestCase):
 
         inputs = tokenizer(input_text, return_tensors="pt", padding=True).to(model.device)
         output = model.generate(**inputs, max_new_tokens=20, do_sample=False)
-        output_text = tokenizer.batch_decode(output, skip_special_tokens=False)
+        output_text = tokenizer.batch_decode(output, skip_special_tokens=True)
         return output_text
 
     # ------------------------
@@ -314,38 +305,38 @@ if __name__ == "__main__":
     # Shared parameterization
     # ------------------------
     PARAMETERS = [
-        (False, "120b", False, "eager", "eval"),
-        (False, "120b", False, "eager", "train"),
-        (False, "120b", False, "ft-hf-o-c/vllm-flash-attn3", "eval"),
-        (False, "120b", False, "ft-hf-o-c/vllm-flash-attn3", "train"),
-        (False, "120b", True, "eager", "eval"),
-        (False, "120b", True, "eager", "train"),
-        (False, "120b", True, "ft-hf-o-c/vllm-flash-attn3", "eval"),
-        (False, "120b", True, "ft-hf-o-c/vllm-flash-attn3", "train"),
-        (True, "120b", False, "eager", "eval"),
-        (True, "120b", False, "eager", "train"),
-        (True, "120b", False, "ft-hf-o-c/vllm-flash-attn3", "eval"),
-        (True, "120b", False, "ft-hf-o-c/vllm-flash-attn3", "train"),
-        (True, "120b", True, "eager", "eval"),
-        (True, "120b", True, "eager", "train"),
-        (True, "120b", True, "ft-hf-o-c/vllm-flash-attn3", "eval"),
-        (True, "120b", True, "ft-hf-o-c/vllm-flash-attn3", "train"),
         (False, "20b", False, "eager", "eval"),
         (False, "20b", False, "eager", "train"),
-        (False, "20b", False, "ft-hf-o-c/vllm-flash-attn3", "eval"),
-        (False, "20b", False, "ft-hf-o-c/vllm-flash-attn3", "train"),
+        (False, "20b", False, "kernels-community/vllm-flash-attn3", "eval"),
+        (False, "20b", False, "kernels-community/vllm-flash-attn3", "train"),
         (False, "20b", True, "eager", "eval"),
         (False, "20b", True, "eager", "train"),
-        (False, "20b", True, "ft-hf-o-c/vllm-flash-attn3", "eval"),
-        (False, "20b", True, "ft-hf-o-c/vllm-flash-attn3", "train"),
+        (False, "20b", True, "kernels-community/vllm-flash-attn3", "eval"),
+        (False, "20b", True, "kernels-community/vllm-flash-attn3", "train"),
         (True, "20b", False, "eager", "eval"),
         (True, "20b", False, "eager", "train"),
-        (True, "20b", False, "ft-hf-o-c/vllm-flash-attn3", "eval"),
-        (True, "20b", False, "ft-hf-o-c/vllm-flash-attn3", "train"),
+        (True, "20b", False, "kernels-community/vllm-flash-attn3", "eval"),
+        (True, "20b", False, "kernels-community/vllm-flash-attn3", "train"),
         (True, "20b", True, "eager", "eval"),
         (True, "20b", True, "eager", "train"),
-        (True, "20b", True, "ft-hf-o-c/vllm-flash-attn3", "eval"),
-        (True, "20b", True, "ft-hf-o-c/vllm-flash-attn3", "train"),
+        (True, "20b", True, "kernels-community/vllm-flash-attn3", "eval"),
+        (True, "20b", True, "kernels-community/vllm-flash-attn3", "train"),
+        (False, "120b", False, "eager", "eval"),
+        (False, "120b", False, "eager", "train"),
+        (False, "120b", False, "kernels-community/vllm-flash-attn3", "eval"),
+        (False, "120b", False, "kernels-community/vllm-flash-attn3", "train"),
+        (False, "120b", True, "eager", "eval"),
+        (False, "120b", True, "eager", "train"),
+        (False, "120b", True, "kernels-community/vllm-flash-attn3", "eval"),
+        (False, "120b", True, "kernels-community/vllm-flash-attn3", "train"),
+        (True, "120b", False, "eager", "eval"),
+        (True, "120b", False, "eager", "train"),
+        (True, "120b", False, "kernels-community/vllm-flash-attn3", "eval"),
+        (True, "120b", False, "kernels-community/vllm-flash-attn3", "train"),
+        (True, "120b", True, "eager", "eval"),
+        (True, "120b", True, "eager", "train"),
+        (True, "120b", True, "kernels-community/vllm-flash-attn3", "eval"),
+        (True, "120b", True, "kernels-community/vllm-flash-attn3", "train"),
     ]
 
     # ------------------------
@@ -354,7 +345,7 @@ if __name__ == "__main__":
     @parameterized.expand(PARAMETERS)
     @require_read_token
     def test_model_outputs(self, quantized, model, kernels, attn_impl, mode):
-        model_id = f"/fsx/vb/new-oai/gpt-oss-{model}-trfs"
+        model_id = f"openai/gpt-oss-{model}"
         output_texts = self.load_and_forward(
             model_id,
             attn_impl,
@@ -362,23 +353,50 @@ if __name__ == "__main__":
             use_kernels=kernels,
         )
 
-        result_entry = {
-            "quantized": quantized,
-            "model": model,
-            "kernels": kernels,
-            "attn_impl": attn_impl,
-            "mode": mode,
-            "outputs": output_texts,
-        }
+        # Generate key to look up expected outputs
+        key = self.generate_config_key(quantized, model, kernels, attn_impl, mode)
 
+        # Load expected outputs from restructured JSON
         if os.path.exists(RESULTS_PATH):
             with open(RESULTS_PATH, "r") as f:
-                results = json.load(f)
-        else:
-            results = []
-        results.append(result_entry)
-        with open(RESULTS_PATH, "w") as f:
-            json.dump(results, f, indent=2)
+                expected_results = json.load(f)
+
+            # Check if we have expected results for this configuration
+            if key in expected_results:
+                expected_outputs = expected_results[key]
+
+                # Compare actual outputs with expected outputs
+                self.assertEqual(len(output_texts), len(expected_outputs), f"Output length mismatch for {key}")
+
+                for i, (actual, expected) in enumerate(zip(output_texts, expected_outputs)):
+                    actual_stripped = actual.strip()
+                    expected_stripped = expected.strip()
+
+                    # Make lengths match by taking minimum length to be resilient to generation differences
+                    min_length = min(len(actual_stripped), len(expected_stripped))
+                    actual_truncated = actual_stripped[:min_length]
+                    expected_truncated = expected_stripped[:min_length]
+
+                    if actual_truncated != expected_truncated:
+                        diff = "\n".join(
+                            difflib.unified_diff(
+                                expected_truncated.splitlines(keepends=True),
+                                actual_truncated.splitlines(keepends=True),
+                                fromfile=f"expected[{i}]",
+                                tofile=f"actual[{i}]",
+                                lineterm="",
+                            )
+                        )
+                        self.fail(
+                            f"Output mismatch at index {i} for {key}:\n"
+                            f"Expected: '{expected_stripped}'\n"
+                            f"Actual:   '{actual_stripped}'\n"
+                            f"Diff (truncated to min length {min_length}):\n{diff}"
+                        )
+            else:
+                # If no expected results exist, this is a new configuration
+                # We could optionally add it to the results file here
+                print(f"Warning: No expected results found for configuration: {key}")
 
         self.assertIsInstance(output_texts, list)
         self.assertTrue(all(isinstance(x, str) for x in output_texts))
@@ -391,6 +409,51 @@ if __name__ == "__main__":
     def test_model_outputs_distributed(self, quantized, model, kernels, attn_impl, mode):
         self.run_distributed_test(quantized, model, kernels, attn_impl, mode)
 
+    # ------------------------
+    # Training test
+    # ------------------------
+    @parameterized.expand(PARAMETERS)
+    @require_read_token
+    def test_training_step(self, quantized, model, kernels, attn_impl, mode):
+        if mode != "train":
+            self.skipTest("This test is only for training mode.")
+
+        if quantized:
+            self.skipTest("Training test for quantized models is not supported.")
+
+        model_id = f"openai/gpt-oss-{model}"
+
+        model_obj = AutoModelForCausalLM.from_pretrained(
+            model_id,
+            dtype=torch.bfloat16,
+            device_map="auto",
+            attn_implementation=attn_impl,
+            use_kernels=kernels,
+        )
+        model_obj.train()
+
+        tokenizer = AutoTokenizer.from_pretrained(model_id, padding_side="left")
+        if tokenizer.pad_token is None:
+            tokenizer.pad_token = tokenizer.eos_token
+
+        inputs = tokenizer(self.input_text, return_tensors="pt", padding=True).to(model_obj.device)
+        inputs["labels"] = inputs["input_ids"].clone()
+
+        outputs = model_obj(**inputs)
+        loss = outputs.loss
+        self.assertIsNotNone(loss)
+
+        loss.backward()
+
+        # Check that gradients were computed for all parameters that have a grad field
+        for name, param in model_obj.named_parameters():
+            if param.requires_grad:
+                self.assertIsNotNone(param.grad, f"Parameter '{name}' did not receive a gradient.")
+                # Check that gradients are not all zero
+                self.assertTrue(
+                    torch.sum(torch.abs(param.grad)).item() > 0, f"Gradient for parameter '{name}' is all zeros."
+                )
+
     def test_model_matches_original_20b(self):
         input_text = "Roses are red, violets"
 
@@ -420,11 +483,11 @@ if __name__ == "__main__":
             ]
         )
 
-        model_id = "/fsx/vb/new-oai/gpt-oss-20b-trfs"
+        model_id = "openai/gpt-oss-20b"
 
         model = AutoModelForCausalLM.from_pretrained(
             model_id,
-            torch_dtype=torch.bfloat16,
+            dtype=torch.bfloat16,
             device_map="auto",
             attn_implementation="eager",
         )
@@ -486,11 +549,11 @@ I am a language model, not a human being"""
             ]
         )
 
-        model_id = "/fsx/vb/new-oai/gpt-oss-120b-trfs"
+        model_id = "openai/gpt-oss-120b"
 
         model = AutoModelForCausalLM.from_pretrained(
             model_id,
-            torch_dtype=torch.bfloat16,
+            dtype=torch.bfloat16,
             device_map="auto",
             attn_implementation="eager",
         )
