@@ -604,9 +604,9 @@ class MaskFormerModelIntegrationTest(unittest.TestCase):
                     [1.0766e-04, -7.7630e00, -5.1263e00],
                 ],
                 ("cuda", 8): [
-                    [1.6507e00, -5.2568e00, -3.3520e00],
-                    [3.5767e-02, -5.9023e00, -2.9313e00],
-                    [-6.2712e-04, -7.7627e00, -5.1268e00],
+                    [1.6512e00, -5.2572e00, -3.3519e00],
+                    [3.6163e-02, -5.9025e00, -2.9313e00],
+                    [1.1681e-04, -7.7631e00, -5.1263e00],
                 ],
             }
         )
@@ -641,7 +641,7 @@ class MaskFormerModelIntegrationTest(unittest.TestCase):
         expectations = Expectations(
             {
                 (None, None): [[-0.9046, -2.6366, -4.6062], [-3.4179, -5.7890, -8.8057], [-4.9179, -7.6560, -10.7711]],
-                ("cuda", 8): [[-0.9000, -2.6283, -4.5964], [-3.4123, -5.7789, -8.7919], [-4.9132, -7.6444, -10.7557]],
+                ("cuda", 8): [[-0.9046, -2.6366, -4.6062], [-3.4179, -5.7890, -8.8057], [-4.9179, -7.6560, -10.7711]],
             }
         )
         expected_slice = torch.tensor(expectations.get_expectation()).to(torch_device)
@@ -659,9 +659,9 @@ class MaskFormerModelIntegrationTest(unittest.TestCase):
                     [7.2449, -2.2764, -2.1874],
                 ],
                 ("cuda", 8): [
-                    [4.7177, -3.2586, -2.8853],
-                    [6.6845, -2.9186, -1.2491],
-                    [7.2443, -2.2760, -2.1858],
+                    [4.7188, -3.2585, -2.8857],
+                    [6.6871, -2.9181, -1.2487],
+                    [7.2449, -2.2764, -2.1874],
                 ],
             }
         )
