@@ -35,7 +35,6 @@ from transformers.testing_utils import (
     is_torch_available,
     require_torch,
     require_torch_fp16,
-    require_torch_sdpa,
     slow,
     torch_device,
 )
@@ -178,6 +177,7 @@ class MoshiDecoderTest(ModelTesterMixin, GenerationTesterMixin, PipelineTesterMi
         )
 
     @unittest.skip(reason="The MoshiModel does not have support dynamic compile yet")
+    @pytest.mark.torch_compile_test
     def test_sdpa_can_compile_dynamic(self):
         pass
 
@@ -193,11 +193,10 @@ class MoshiDecoderTest(ModelTesterMixin, GenerationTesterMixin, PipelineTesterMi
         return logits_processor_kwargs
 
     @parameterized.expand(TEST_EAGER_MATCHES_SDPA_INFERENCE_PARAMETERIZATION)
-    @require_torch_sdpa
     def test_eager_matches_sdpa_inference(
-        self, name, torch_dtype, padding_side, use_attention_mask, output_attentions, enable_kernels
+        self, name, dtype, padding_side, use_attention_mask, output_attentions, enable_kernels
     ):
-        if use_attention_mask or (not use_attention_mask and torch_dtype == "fp32" and not output_attentions):
+        if use_attention_mask or (not use_attention_mask and dtype == "fp32" and not output_attentions):
             self.skipTest("Test is failing, fix me :) ")
         parent_parameterized_test = getattr(ModelTesterMixin, self._testMethodName)
         parent_parameterized_test(self)
@@ -631,11 +630,12 @@ class MoshiTest(ModelTesterMixin, GenerationTesterMixin, unittest.TestCase):
     @parameterized.expand(TEST_EAGER_MATCHES_SDPA_INFERENCE_PARAMETERIZATION)
     @unittest.skip(reason="Unimplemented. Relies on `test_eager_matches_sdpa_generate` to check correctness.")
     def test_eager_matches_sdpa_inference(
-        self, name, torch_dtype, padding_side, use_attention_mask, output_attentions, enable_kernels
+        self, name, dtype, padding_side, use_attention_mask, output_attentions, enable_kernels
     ):
         pass
 
     @unittest.skip(reason="The Moshi model does not have support dynamic compile yet")
+    @pytest.mark.torch_compile_test
     def test_sdpa_can_compile_dynamic(self):
         pass
 
@@ -690,7 +690,6 @@ class MoshiTest(ModelTesterMixin, GenerationTesterMixin, unittest.TestCase):
             # They should result in very similar logits
             torch.testing.assert_close(next_logits_wo_padding, next_logits_with_padding, rtol=1e-5, atol=1e-5)
 
-    @require_torch_sdpa
     @slow
     @is_flaky(max_attempts=5, description="flaky on some models.")
     def test_eager_matches_sdpa_generate(self):
@@ -721,14 +720,14 @@ class MoshiTest(ModelTesterMixin, GenerationTesterMixin, unittest.TestCase):
 
                 model_sdpa = model_class.from_pretrained(
                     tmpdirname,
-                    torch_dtype=torch.float16,
+                    dtype=torch.float16,
                 ).to(torch_device)
 
                 self.assertTrue(model_sdpa.config._attn_implementation == "sdpa")
 
                 model_eager = model_class.from_pretrained(
                     tmpdirname,
-                    torch_dtype=torch.float16,
+                    dtype=torch.float16,
                     attn_implementation="eager",
                 ).to(torch_device)
 
@@ -909,7 +908,7 @@ class MoshiIntegrationTests(unittest.TestCase):
     @slow
     def test_moshika_conditional_greedy(self):
         model = MoshiForConditionalGeneration.from_pretrained(
-            "kmhf/hf-moshika", torch_dtype=torch.float16, device_map="auto"
+            "kmhf/hf-moshika", dtype=torch.float16, device_map="auto"
         )
         inputs = self.feature_extractor(self._load_datasample(), return_tensors="pt").to(
             device=torch_device, dtype=torch.float16
@@ -954,7 +953,7 @@ class MoshiIntegrationTests(unittest.TestCase):
     @slow
     def test_moshiko_greedy_unconditional_fp16_eager(self):
         model = MoshiForConditionalGeneration.from_pretrained(
-            "kmhf/hf-moshiko", torch_dtype=torch.float16, device_map="auto"
+            "kmhf/hf-moshiko", dtype=torch.float16, device_map="auto"
         )
         some_expected_audio_tokens = [[1049, 127], [1700, 243], [1626, 457], [546, 290], [306, 306], [1443, 1443], [1871, 428], [2008, 1744]]  # fmt: skip
 
@@ -968,7 +967,7 @@ class MoshiIntegrationTests(unittest.TestCase):
     @slow
     def test_moshiko_greedy_unconditional_fp32(self):
         model = MoshiForConditionalGeneration.from_pretrained(
-            "kmhf/hf-moshiko", torch_dtype=torch.float32, device_map="auto"
+            "kmhf/hf-moshiko", dtype=torch.float32, device_map="auto"
         )
 
         expected_audio_codesum = 72065
@@ -990,7 +989,7 @@ class MoshiIntegrationTests(unittest.TestCase):
     @require_torch_fp16
     def test_moshiko_greedy_unconditional_fp16(self):
         model = MoshiForConditionalGeneration.from_pretrained(
-            "kmhf/hf-moshiko", torch_dtype=torch.float16, device_map="auto"
+            "kmhf/hf-moshiko", dtype=torch.float16, device_map="auto"
         )
 
         expected_audio_codesum = 72065
@@ -1012,7 +1011,7 @@ class MoshiIntegrationTests(unittest.TestCase):
     @require_torch_fp16
     def test_moshika_greedy_unconditional_fp16(self):
         model = MoshiForConditionalGeneration.from_pretrained(
-            "kmhf/hf-moshika", torch_dtype=torch.float16, device_map="auto"
+            "kmhf/hf-moshika", dtype=torch.float16, device_map="auto"
         )
 
         expected_audio_codesum = 72932
