@@ -440,7 +440,7 @@ class VitsModelIntegrationTests(unittest.TestCase):
         # GPU gives different results than CPU
         torch_device = "cpu"
 
-        model = VitsModel.from_pretrained("facebook/mms-tts-eng", torch_dtype=torch.float16)
+        model = VitsModel.from_pretrained("facebook/mms-tts-eng", dtype=torch.float16)
         model.to(torch_device)
 
         tokenizer = VitsTokenizer.from_pretrained("facebook/mms-tts-eng")
