@@ -207,7 +207,7 @@ class GgufIntegrationTests(unittest.TestCase):
 
         tokenizer = AutoTokenizer.from_pretrained(self.gguf_model_id, gguf_file=q6_k_gguf_model_id)
         model = AutoModelForCausalLM.from_pretrained(
-            self.gguf_model_id, gguf_file=q6_k_gguf_model_id, torch_dtype=torch.float16
+            self.gguf_model_id, gguf_file=q6_k_gguf_model_id, dtype=torch.float16
         ).to(torch_device)
 
         self.assertTrue(model.lm_head.weight.dtype == torch.float16)
@@ -279,7 +279,7 @@ class GgufModelTests(unittest.TestCase):
     falcon7b_model_id_fp16 = "medmekk/falcon-7b-gguf"
     falcon40b_model_id = "maddes8cht/tiiuae-falcon-40b-gguf"
     original_flacon7b_model_id = "tiiuae/falcon-7b"
-    t5_model_id = "repetitio/flan-t5-small"
+    t5_model_id = "Felladrin/gguf-flan-t5-small"
     original_t5_model_id = "google/flan-t5-small"
     stablelm_model_id = "afrideva/stablelm-3b-4e1t-GGUF"
     stablelm2_model_id = "afrideva/stablelm-2-1_6b-GGUF"
@@ -317,8 +317,8 @@ class GgufModelTests(unittest.TestCase):
     q2_k_falcon7b_model_id = "falcon-7b-q2_k.gguf"
     fp16_falcon7b_model_id = "falcon-7b-fp16.gguf"
     q2_k_falcon40b_model_id = "tiiuae-falcon-40b-Q2_K.gguf"
-    fp16_t5_model_id = "flan-t5-small-f16.gguf"
-    q8_0_t5_model_id = "flan-t5-small-q8_0.gguf"
+    fp16_t5_model_id = "flan-t5-small.F16.gguf"
+    q8_0_t5_model_id = "flan-t5-small.Q8_0.gguf"
     fp16_qwen2moe_model_id = "Qwen1.5-MoE-A2.7B.gguf"
     fp16_gpt2_model_id = "gpt2.f16.gguf"
     q8_gpt2_model_id = "gpt2.Q8_0.gguf"
@@ -335,6 +335,10 @@ class GgufModelTests(unittest.TestCase):
     q4_0_gemma3_qat_model_id = "gemma-3-1b-it-q4_0.gguf"
     bf16_gemma3_text_model_id = "gemma-3-1b-it-BF16.gguf"
     bf16_gemma3_vision_model_id = "gemma-3-4b-it-BF16.gguf"
+    deci_original_model_id = "Deci/DeciLM-7B"
+    deci_model_id = "Deci/DeciLM-7B-instruct-GGUF"
+    q8_0_deci_model_id = "decilm-7b-uniform-gqa-q8_0.gguf"
+    fp16_deci_model_id = "decilm-7b-uniform-gqa-f16.gguf"
     q8_0_qwen3_model_id = "Qwen3-0.6B-Q8_0.gguf"
     q4_k_m_qwen3moe_model_id = "Qwen3-30B-A3B-Q4_K_M.gguf"
 
@@ -346,7 +350,7 @@ class GgufModelTests(unittest.TestCase):
             self.mistral_model_id,
             gguf_file=self.q4_0_mistral_model_id,
             device_map="auto",
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
 
         text = tokenizer(self.example_text, return_tensors="pt").to(torch_device)
@@ -361,7 +365,7 @@ class GgufModelTests(unittest.TestCase):
             self.qwen2_model_id,
             gguf_file=self.q4_0_qwen2_model_id,
             device_map="auto",
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
 
         text = tokenizer(self.example_text, return_tensors="pt").to(torch_device)
@@ -375,7 +379,7 @@ class GgufModelTests(unittest.TestCase):
         model = AutoModelForCausalLM.from_pretrained(
             self.qwen2moe_model_id,
             gguf_file=self.q8_qwen2moe_model_id,
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
 
         text = tokenizer(self.example_text, return_tensors="pt")
@@ -388,11 +392,11 @@ class GgufModelTests(unittest.TestCase):
         quantized_model = AutoModelForCausalLM.from_pretrained(
             self.qwen2moe_model_id,
             gguf_file=self.fp16_qwen2moe_model_id,
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
         original_model = AutoModelForCausalLM.from_pretrained(
             self.qwen2moe_original_model_id,
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
 
         quantized_state_dict = quantized_model.state_dict()
@@ -406,7 +410,7 @@ class GgufModelTests(unittest.TestCase):
     def test_phi3_q4_0(self):
         tokenizer = AutoTokenizer.from_pretrained(self.phi3_model_id, gguf_file=self.q4_0_phi3_model_id)
         model = AutoModelForCausalLM.from_pretrained(
-            self.phi3_model_id, gguf_file=self.q4_0_phi3_model_id, device_map="auto", torch_dtype=torch.float16
+            self.phi3_model_id, gguf_file=self.q4_0_phi3_model_id, device_map="auto", dtype=torch.float16
         )
 
         text = tokenizer(self.example_text, return_tensors="pt").to(torch_device)
@@ -430,7 +434,7 @@ class GgufModelTests(unittest.TestCase):
             self.llama3_model_id,
             gguf_file=self.q4_llama3_model_id,
             device_map="auto",
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
 
         text = tokenizer(self.example_text, return_tensors="pt").to(torch_device)
@@ -445,7 +449,7 @@ class GgufModelTests(unittest.TestCase):
             self.bloom_model_id,
             gguf_file=self.fp16_bloom_model_id,
             device_map="auto",
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
 
         text = tokenizer(self.example_text, return_tensors="pt").to(torch_device)
@@ -460,7 +464,7 @@ class GgufModelTests(unittest.TestCase):
             self.bloom_model_id,
             gguf_file=self.q8_bloom_model_id,
             device_map="auto",
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
 
         text = tokenizer(self.example_text, return_tensors="pt").to(torch_device)
@@ -474,12 +478,12 @@ class GgufModelTests(unittest.TestCase):
             self.bloom_model_id,
             gguf_file=self.fp16_bloom_model_id,
             device_map="auto",
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
         original_model = AutoModelForCausalLM.from_pretrained(
             self.original_bloom_model_id,
             device_map="auto",
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
 
         quantized_state_dict = quantized_model.state_dict()
@@ -498,7 +502,7 @@ class GgufModelTests(unittest.TestCase):
     def test_t5_f16(self):
         tokenizer = AutoTokenizer.from_pretrained(self.t5_model_id, gguf_file=self.fp16_t5_model_id)
         model = AutoModelForSeq2SeqLM.from_pretrained(
-            self.t5_model_id, gguf_file=self.fp16_t5_model_id, device_map="auto", torch_dtype=torch.float16
+            self.t5_model_id, gguf_file=self.fp16_t5_model_id, device_map="auto", dtype=torch.float16
         )
 
         T5_EXAMPLE_TEXT = "translate English to German: How old are you?"
@@ -512,7 +516,7 @@ class GgufModelTests(unittest.TestCase):
     def test_t5_q8_0(self):
         tokenizer = AutoTokenizer.from_pretrained(self.t5_model_id, gguf_file=self.q8_0_t5_model_id)
         model = AutoModelForSeq2SeqLM.from_pretrained(
-            self.t5_model_id, gguf_file=self.q8_0_t5_model_id, device_map="auto", torch_dtype=torch.float16
+            self.t5_model_id, gguf_file=self.q8_0_t5_model_id, device_map="auto", dtype=torch.float16
         )
 
         T5_EXAMPLE_TEXT = "translate English to German: How old are you?"
@@ -528,12 +532,12 @@ class GgufModelTests(unittest.TestCase):
             self.t5_model_id,
             gguf_file=self.fp16_t5_model_id,
             device_map="auto",
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
         original_model = AutoModelForSeq2SeqLM.from_pretrained(
             self.original_t5_model_id,
             device_map="auto",
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
 
         quantized_state_dict = quantized_model.state_dict()
@@ -550,7 +554,7 @@ class GgufModelTests(unittest.TestCase):
         model = AutoModelForCausalLM.from_pretrained(
             self.gpt2_model_id,
             gguf_file=self.q8_gpt2_model_id,
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
 
         text = tokenizer(self.example_text, return_tensors="pt")
@@ -563,11 +567,11 @@ class GgufModelTests(unittest.TestCase):
         quantized_model = AutoModelForCausalLM.from_pretrained(
             self.gpt2_model_id,
             gguf_file=self.fp16_gpt2_model_id,
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
         original_model = AutoModelForCausalLM.from_pretrained(
             self.gpt2_original_model_id,
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
 
         quantized_state_dict = quantized_model.state_dict()
@@ -585,7 +589,7 @@ class GgufModelTests(unittest.TestCase):
         model = AutoModelForCausalLM.from_pretrained(
             self.gpt2_xl_model_id,
             gguf_file=self.q6_k_gpt2_xl_model_id,
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
 
         text = tokenizer(self.example_text, return_tensors="pt")
@@ -601,7 +605,7 @@ class GgufModelTests(unittest.TestCase):
             self.falcon40b_model_id,
             gguf_file=self.q2_k_falcon40b_model_id,
             device_map="auto",
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
 
         text = tokenizer(self.example_text, return_tensors="pt").to(torch_device)
@@ -616,7 +620,7 @@ class GgufModelTests(unittest.TestCase):
             self.falcon7b_model_id_q2,
             gguf_file=self.q2_k_falcon7b_model_id,
             device_map="auto",
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
 
         text = tokenizer(self.example_text, return_tensors="pt")["input_ids"].to(torch_device)
@@ -631,12 +635,12 @@ class GgufModelTests(unittest.TestCase):
             self.falcon7b_model_id_fp16,
             gguf_file=self.fp16_falcon7b_model_id,
             device_map="auto",
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
         original_model = AutoModelForCausalLM.from_pretrained(
             self.original_flacon7b_model_id,
             device_map="auto",
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
 
         quantized_state_dict = quantized_model.state_dict()
@@ -654,7 +658,7 @@ class GgufModelTests(unittest.TestCase):
             self.stablelm_model_id,
             gguf_file=self.q4_k_m_stablelm_model_id,
             device_map="auto",
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
 
         tokenizer = AutoTokenizer.from_pretrained(self.stablelm_model_id, gguf_file=self.q4_k_m_stablelm_model_id)
@@ -667,13 +671,13 @@ class GgufModelTests(unittest.TestCase):
     def test_stablelm_fp16(self):
         original_model = AutoModelForCausalLM.from_pretrained(
             self.original_stablelm2_model_id,
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
 
         converted_model = AutoModelForCausalLM.from_pretrained(
             self.stablelm2_model_id,
             gguf_file=self.fp16_stablelm2_model_id,
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
 
         tokenizer = AutoTokenizer.from_pretrained(self.stablelm2_model_id, gguf_file=self.fp16_stablelm2_model_id)
@@ -692,14 +696,14 @@ class GgufModelTests(unittest.TestCase):
         original_model = AutoModelForCausalLM.from_pretrained(
             self.original_stablelm2_model_id,
             device_map="auto",
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
 
         converted_model = AutoModelForCausalLM.from_pretrained(
             self.stablelm2_model_id,
             gguf_file=self.fp16_stablelm2_model_id,
             device_map="auto",
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
 
         converted_state_dict = converted_model.state_dict()
@@ -716,14 +720,14 @@ class GgufModelTests(unittest.TestCase):
         original_model = AutoModelForCausalLM.from_pretrained(
             self.starcoder2_original_model_id,
             device_map="auto",
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
 
         converted_model = AutoModelForCausalLM.from_pretrained(
             self.starcoder2_fp16_model_id,
             gguf_file=self.fp16_starcoder2_gguf_model_id,
             device_map="auto",
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
 
         converted_state_dict = converted_model.state_dict()
@@ -742,7 +746,7 @@ class GgufModelTests(unittest.TestCase):
             self.starcoder2_model_id,
             gguf_file=self.q6_k_starcoder2_model_id,
             device_map="auto",
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
 
         tokenizer = AutoTokenizer.from_pretrained(self.starcoder2_model_id, gguf_file=self.q6_k_starcoder2_model_id)
@@ -755,13 +759,13 @@ class GgufModelTests(unittest.TestCase):
     def test_mamba_weights_conversion_fp16(self):
         original_model = AutoModelForCausalLM.from_pretrained(
             self.mamba_original_model_id,
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
 
         converted_model = AutoModelForCausalLM.from_pretrained(
             self.mamba_model_id,
             gguf_file=self.fp16_mamba_model_id,
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
 
         converted_state_dict = converted_model.state_dict()
@@ -783,7 +787,7 @@ class GgufModelTests(unittest.TestCase):
         model = AutoModelForCausalLM.from_pretrained(
             self.mamba_model_id,
             gguf_file=self.q6_k_mamba_model_id,
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
 
         tokenizer = AutoTokenizer.from_pretrained(self.mamba_model_id, gguf_file=self.q6_k_mamba_model_id)
@@ -796,13 +800,13 @@ class GgufModelTests(unittest.TestCase):
     def test_nemotron_weights_conversion_fp16(self):
         original_model = AutoModelForCausalLM.from_pretrained(
             self.nemotron_original_model_id,
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
 
         converted_model = AutoModelForCausalLM.from_pretrained(
             self.nemotron_model_id,
             gguf_file=self.fp16_nemotron_model_id,
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
 
         converted_state_dict = converted_model.state_dict()
@@ -819,10 +823,10 @@ class GgufModelTests(unittest.TestCase):
         model = AutoModelForCausalLM.from_pretrained(
             self.nemotron_model_id,
             gguf_file=self.q6_k_nemotron_model_id,
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
-
-        tokenizer = AutoTokenizer.from_pretrained(self.nemotron_model_id, gguf_file=self.q6_k_nemotron_model_id)
+        # use the original tokenizer from nvidia to avoid long load times
+        tokenizer = AutoTokenizer.from_pretrained("nvidia/Nemotron-Mini-4B-Instruct")
         text = tokenizer(self.example_text, return_tensors="pt")["input_ids"]
         out = model.generate(text, max_new_tokens=16)
 
@@ -833,7 +837,7 @@ class GgufModelTests(unittest.TestCase):
         model = AutoModelForCausalLM.from_pretrained(
             self.gemma2_model_id,
             gguf_file=self.q3_k_gemma2_model_id,
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
 
         tokenizer = AutoTokenizer.from_pretrained(self.gemma2_model_id, gguf_file=self.q3_k_gemma2_model_id)
@@ -847,7 +851,7 @@ class GgufModelTests(unittest.TestCase):
         model = AutoModelForCausalLM.from_pretrained(
             self.gemma2_model_id,
             gguf_file=self.q8_0_gemma2_model_id,
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
 
         tokenizer = AutoTokenizer.from_pretrained(self.gemma2_model_id, gguf_file=self.q8_0_gemma2_model_id)
@@ -861,7 +865,7 @@ class GgufModelTests(unittest.TestCase):
         model = AutoModelForCausalLM.from_pretrained(
             self.gemma2_model_id,
             gguf_file=self.fp32_gemma2_model_id,
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
 
         tokenizer = AutoTokenizer.from_pretrained(self.gemma2_model_id, gguf_file=self.fp32_gemma2_model_id)
@@ -875,13 +879,13 @@ class GgufModelTests(unittest.TestCase):
     def test_gemma2_weights_conversion_fp32(self):
         original_model = AutoModelForCausalLM.from_pretrained(
             self.original_gemma2_model_id,
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
 
         converted_model = AutoModelForCausalLM.from_pretrained(
             self.gemma2_model_id,
             gguf_file=self.fp32_gemma2_model_id,
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
 
         converted_state_dict = converted_model.state_dict()
@@ -900,7 +904,7 @@ class GgufModelTests(unittest.TestCase):
         model = AutoModelForCausalLM.from_pretrained(
             self.gemma3_qat_model_id,
             gguf_file=self.q4_0_gemma3_qat_model_id,
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
 
         tokenizer = AutoTokenizer.from_pretrained(self.gemma3_qat_model_id, gguf_file=self.q4_0_gemma3_qat_model_id)
@@ -916,13 +920,13 @@ class GgufModelTests(unittest.TestCase):
     def test_gemma3_text_weights_conversion_bf16(self):
         original_model = AutoModelForCausalLM.from_pretrained(
             self.original_gemma3_text_model_id,
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
 
         converted_model = AutoModelForCausalLM.from_pretrained(
             self.gemma3_text_model_id,
             gguf_file=self.bf16_gemma3_text_model_id,
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
 
         converted_state_dict = converted_model.state_dict()
@@ -941,15 +945,59 @@ class GgufModelTests(unittest.TestCase):
     def test_gemma3_vision_weights_conversion_bf16(self):
         original_model = AutoModelForCausalLM.from_pretrained(
             self.original_gemma3_vision_model_id,
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         ).language_model
 
         converted_model = AutoModelForCausalLM.from_pretrained(
             self.gemma3_vision_model_id,
             gguf_file=self.bf16_gemma3_vision_model_id,
+            dtype=torch.float16,
+        ).model
+
+        converted_state_dict = converted_model.state_dict()
+        original_state_dict = original_model.state_dict()
+
+        for layer_name, original_params in original_state_dict.items():
+            if layer_name in converted_state_dict:
+                self.assertTrue(original_params.shape == converted_state_dict[layer_name].shape)
+                torch.testing.assert_close(original_params, converted_state_dict[layer_name])
+            else:
+                raise ValueError(f"Layer {layer_name} is not presented in GGUF model")
+
+    def test_deci_q8_0(self):
+        """Test Deci model loading and inference with Q4_0 quantization."""
+        tokenizer = AutoTokenizer.from_pretrained(self.deci_model_id, gguf_file=self.q8_0_deci_model_id)
+        model = AutoModelForCausalLM.from_pretrained(
+            self.deci_model_id,
+            gguf_file=self.q8_0_deci_model_id,
+            device_map="auto",
             torch_dtype=torch.float16,
         )
 
+        text = tokenizer(self.example_text, return_tensors="pt").to(torch_device)
+        out = model.generate(**text, max_new_tokens=10)
+
+        EXPECTED_TEXT = "Hello, I am a language model developed"
+        self.assertEqual(tokenizer.decode(out[0], skip_special_tokens=True), EXPECTED_TEXT)
+
+    def test_deci_weights_conversion_fp16(self):
+        """Test that GGUF Deci model weights match the original model weights."""
+        original_model_id = "Deci/DeciLM-7B"
+        original_model = AutoModelForCausalLM.from_pretrained(
+            original_model_id,
+            torch_dtype=torch.float16,
+            trust_remote_code=True,
+            device_map="auto",
+        )
+        # You need to have an FP16 version of your GGUF model for accurate comparison
+
+        converted_model = AutoModelForCausalLM.from_pretrained(
+            self.deci_model_id,
+            gguf_file=self.fp16_deci_model_id,
+            torch_dtype=torch.float16,
+            device_map="auto",
+        )
+
         converted_state_dict = converted_model.state_dict()
         original_state_dict = original_model.state_dict()
 
@@ -960,6 +1008,41 @@ class GgufModelTests(unittest.TestCase):
             else:
                 raise ValueError(f"Layer {layer_name} is not presented in GGUF model")
 
+    def test_deci_config_mapping(self):
+        """Test that Deci GGUF config mapping is correctly applied."""
+        from transformers.integrations.ggml import GGUF_CONFIG_MAPPING
+
+        self.assertIn("deci", GGUF_CONFIG_MAPPING)
+
+        deci_mapping = GGUF_CONFIG_MAPPING["deci"]
+
+        expected_mappings = {
+            "context_length": "max_position_embeddings",
+            "block_count": "num_hidden_layers",
+            "feed_forward_length": "intermediate_size",
+            "embedding_length": "hidden_size",
+            "rope.freq_base": "rope_theta",
+            "attention.head_count": "num_attention_heads",
+            "attention.head_count_kv": "num_key_value_heads",
+            "attention.layer_norm_rms_epsilon": "rms_norm_eps",
+            "vocab_size": "vocab_size",
+        }
+
+        for gguf_key, transformers_key in expected_mappings.items():
+            self.assertEqual(deci_mapping[gguf_key], transformers_key)
+
+        self.assertIsNone(deci_mapping["rope.dimension_count"])
+
+    def test_deci_architecture_mapping(self):
+        """Test that Deci architectures are mapped to GGUFLlamaConverter."""
+        from transformers.integrations.ggml import GGUF_TO_FAST_CONVERTERS, GGUFLlamaConverter
+
+        self.assertIn("deci", GGUF_TO_FAST_CONVERTERS)
+        self.assertIn("decilm", GGUF_TO_FAST_CONVERTERS)
+
+        self.assertEqual(GGUF_TO_FAST_CONVERTERS["deci"], GGUFLlamaConverter)
+        self.assertEqual(GGUF_TO_FAST_CONVERTERS["decilm"], GGUFLlamaConverter)
+
     @require_read_token
     @unittest.skipUnless(is_gguf_available("0.16.0"), "test requires gguf version >= 0.16.0")
     def test_qwen3_q8_0(self):
@@ -967,7 +1050,7 @@ class GgufModelTests(unittest.TestCase):
         model = AutoModelForCausalLM.from_pretrained(
             self.qwen3_model_id,
             gguf_file=self.q8_0_qwen3_model_id,
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
 
         text = tokenizer(self.example_text, return_tensors="pt")["input_ids"]
@@ -981,7 +1064,7 @@ class GgufModelTests(unittest.TestCase):
         model = AutoModelForCausalLM.from_pretrained(
             self.qwen3moe_model_id,
             gguf_file=self.q4_k_m_qwen3moe_model_id,
-            torch_dtype=torch.float16,
+            dtype=torch.float16,
         )
 
         text = tokenizer(self.example_text, return_tensors="pt")
