@@ -173,18 +173,18 @@ class PipelineTesterMixin:
     pipeline_model_mapping = None
     supported_frameworks = ["pt", "tf"]
 
-    def run_task_tests(self, task, torch_dtype="float32"):
+    def run_task_tests(self, task, dtype="float32"):
         """Run pipeline tests for a specific `task`
 
         Args:
             task (`str`):
                 A task name. This should be a key in the mapping `pipeline_test_mapping`.
-            torch_dtype (`str`, `optional`, defaults to `'float32'`):
+            dtype (`str`, `optional`, defaults to `'float32'`):
                 The torch dtype to use for the model. Can be used for FP16/other precision inference.
         """
         if task not in self.pipeline_model_mapping:
             self.skipTest(
-                f"{self.__class__.__name__}::test_pipeline_{task.replace('-', '_')}_{torch_dtype} is skipped: `{task}` is not in "
+                f"{self.__class__.__name__}::test_pipeline_{task.replace('-', '_')}_{dtype} is skipped: `{task}` is not in "
                 f"`self.pipeline_model_mapping` for `{self.__class__.__name__}`."
             )
 
@@ -245,7 +245,7 @@ class PipelineTesterMixin:
                 feature_extractor_names=feature_extractor_names,
                 processor_names=processor_names,
                 commit=commit,
-                torch_dtype=torch_dtype,
+                dtype=dtype,
             )
             at_least_one_model_is_tested = True
 
@@ -255,7 +255,7 @@ class PipelineTesterMixin:
 
         if not at_least_one_model_is_tested:
             self.skipTest(
-                f"{self.__class__.__name__}::test_pipeline_{task.replace('-', '_')}_{torch_dtype} is skipped: Could not find any "
+                f"{self.__class__.__name__}::test_pipeline_{task.replace('-', '_')}_{dtype} is skipped: Could not find any "
                 f"model architecture in the tiny models JSON file for `{task}`."
             )
 
@@ -269,7 +269,7 @@ class PipelineTesterMixin:
         feature_extractor_names,
         processor_names,
         commit,
-        torch_dtype="float32",
+        dtype="float32",
     ):
         """Run pipeline tests for a specific `task` with the give model class and tokenizer/processor class names
 
@@ -290,7 +290,7 @@ class PipelineTesterMixin:
                 A list of names of subclasses of `ProcessorMixin`.
             commit (`str`):
                 The commit hash of the model repository on the Hub.
-            torch_dtype (`str`, `optional`, defaults to `'float32'`):
+            dtype (`str`, `optional`, defaults to `'float32'`):
                 The torch dtype to use for the model. Can be used for FP16/other precision inference.
         """
         # Get an instance of the corresponding class `XXXPipelineTests` in order to use `get_test_pipeline` and
@@ -335,7 +335,7 @@ class PipelineTesterMixin:
 
             if do_skip_test_case:
                 logger.warning(
-                    f"{self.__class__.__name__}::test_pipeline_{task.replace('-', '_')}_{torch_dtype} is skipped: test is "
+                    f"{self.__class__.__name__}::test_pipeline_{task.replace('-', '_')}_{dtype} is skipped: test is "
                     f"currently known to fail for: model `{model_architecture.__name__}` | tokenizer "
                     f"`{tokenizer_name}` | image processor `{image_processor_name}` | feature extractor {feature_extractor_name}."
                 )
@@ -350,7 +350,7 @@ class PipelineTesterMixin:
                 feature_extractor_name=feature_extractor_name,
                 processor_name=processor_name,
                 commit=commit,
-                torch_dtype=torch_dtype,
+                dtype=dtype,
             )
 
     def run_pipeline_test(
@@ -363,7 +363,7 @@ class PipelineTesterMixin:
         feature_extractor_name,
         processor_name,
         commit,
-        torch_dtype="float32",
+        dtype="float32",
     ):
         """Run pipeline tests for a specific `task` with the give model class and tokenizer/processor class name
 
@@ -386,7 +386,7 @@ class PipelineTesterMixin:
                 The name of a subclass of `ProcessorMixin`.
             commit (`str`):
                 The commit hash of the model repository on the Hub.
-            torch_dtype (`str`, `optional`, defaults to `'float32'`):
+            dtype (`str`, `optional`, defaults to `'float32'`):
                 The torch dtype to use for the model. Can be used for FP16/other precision inference.
         """
         repo_id = f"{TRANSFORMERS_TINY_MODEL_PATH}/{repo_name}"
@@ -402,7 +402,7 @@ class PipelineTesterMixin:
             model = model_architecture.from_pretrained(repo_id, revision=commit)
         except Exception:
             logger.warning(
-                f"{self.__class__.__name__}::test_pipeline_{task.replace('-', '_')}_{torch_dtype} is skipped: Could not find or load "
+                f"{self.__class__.__name__}::test_pipeline_{task.replace('-', '_')}_{dtype} is skipped: Could not find or load "
                 f"the model from `{repo_id}` with `{model_architecture}`."
             )
             self.skipTest(f"Could not find or load the model from {repo_id} with {model_architecture}.")
@@ -429,7 +429,7 @@ class PipelineTesterMixin:
                     processors[key] = processor
                 except Exception:
                     logger.warning(
-                        f"{self.__class__.__name__}::test_pipeline_{task.replace('-', '_')}_{torch_dtype} is skipped: "
+                        f"{self.__class__.__name__}::test_pipeline_{task.replace('-', '_')}_{dtype} is skipped: "
                         f"Could not load the {key} from `{repo_id}` with `{name}`."
                     )
                     self.skipTest(f"Could not load the {key} from {repo_id} with {name}.")
@@ -439,7 +439,7 @@ class PipelineTesterMixin:
         # TODO: Maybe not upload such problematic tiny models to Hub.
         if tokenizer is None and "image_processor" not in processors and "feature_extractor" not in processors:
             logger.warning(
-                f"{self.__class__.__name__}::test_pipeline_{task.replace('-', '_')}_{torch_dtype} is skipped: Could not find or load "
+                f"{self.__class__.__name__}::test_pipeline_{task.replace('-', '_')}_{dtype} is skipped: Could not find or load "
                 f"any tokenizer / image processor / feature extractor from `{repo_id}`."
             )
             self.skipTest(f"Could not find or load any tokenizer / processor from {repo_id}.")
@@ -447,7 +447,7 @@ class PipelineTesterMixin:
         pipeline_test_class_name = pipeline_test_mapping[task]["test"].__name__
         if self.is_pipeline_test_to_skip_more(pipeline_test_class_name, model.config, model, tokenizer, **processors):
             logger.warning(
-                f"{self.__class__.__name__}::test_pipeline_{task.replace('-', '_')}_{torch_dtype} is skipped: test is "
+                f"{self.__class__.__name__}::test_pipeline_{task.replace('-', '_')}_{dtype} is skipped: test is "
                 f"currently known to fail for: model `{model_architecture.__name__}` | tokenizer "
                 f"`{tokenizer_name}` | image processor `{image_processor_name}` | feature extractor `{feature_extractor_name}`."
             )
@@ -466,12 +466,12 @@ class PipelineTesterMixin:
         # `run_pipeline_test`.
         task_test = pipeline_test_mapping[task]["test"]()
 
-        pipeline, examples = task_test.get_test_pipeline(model, tokenizer, **processors, torch_dtype=torch_dtype)
+        pipeline, examples = task_test.get_test_pipeline(model, tokenizer, **processors, dtype=dtype)
         if pipeline is None:
             # The test can disable itself, but it should be very marginal
             # Concerns: Wav2Vec2ForCTC without tokenizer test (FastTokenizer don't exist)
             logger.warning(
-                f"{self.__class__.__name__}::test_pipeline_{task.replace('-', '_')}_{torch_dtype} is skipped: Could not get the "
+                f"{self.__class__.__name__}::test_pipeline_{task.replace('-', '_')}_{dtype} is skipped: Could not get the "
                 "pipeline for testing."
             )
             self.skipTest(reason="Could not get the pipeline for testing.")
@@ -504,7 +504,7 @@ class PipelineTesterMixin:
     @is_pipeline_test
     @require_torch
     def test_pipeline_audio_classification_fp16(self):
-        self.run_task_tests(task="audio-classification", torch_dtype="float16")
+        self.run_task_tests(task="audio-classification", dtype="float16")
 
     @is_pipeline_test
     def test_pipeline_automatic_speech_recognition(self):
@@ -513,7 +513,7 @@ class PipelineTesterMixin:
     @is_pipeline_test
     @require_torch
     def test_pipeline_automatic_speech_recognition_fp16(self):
-        self.run_task_tests(task="automatic-speech-recognition", torch_dtype="float16")
+        self.run_task_tests(task="automatic-speech-recognition", dtype="float16")
 
     @is_pipeline_test
     @require_vision
@@ -527,7 +527,7 @@ class PipelineTesterMixin:
     @require_timm
     @require_torch
     def test_pipeline_depth_estimation_fp16(self):
-        self.run_task_tests(task="depth-estimation", torch_dtype="float16")
+        self.run_task_tests(task="depth-estimation", dtype="float16")
 
     @is_pipeline_test
     @require_pytesseract
@@ -541,7 +541,7 @@ class PipelineTesterMixin:
     @require_torch
     @require_vision
     def test_pipeline_document_question_answering_fp16(self):
-        self.run_task_tests(task="document-question-answering", torch_dtype="float16")
+        self.run_task_tests(task="document-question-answering", dtype="float16")
 
     @is_pipeline_test
     def test_pipeline_feature_extraction(self):
@@ -550,7 +550,7 @@ class PipelineTesterMixin:
     @is_pipeline_test
     @require_torch
     def test_pipeline_feature_extraction_fp16(self):
-        self.run_task_tests(task="feature-extraction", torch_dtype="float16")
+        self.run_task_tests(task="feature-extraction", dtype="float16")
 
     @is_pipeline_test
     def test_pipeline_fill_mask(self):
@@ -559,7 +559,7 @@ class PipelineTesterMixin:
     @is_pipeline_test
     @require_torch
     def test_pipeline_fill_mask_fp16(self):
-        self.run_task_tests(task="fill-mask", torch_dtype="float16")
+        self.run_task_tests(task="fill-mask", dtype="float16")
 
     @is_pipeline_test
     @require_torch_or_tf
@@ -571,7 +571,7 @@ class PipelineTesterMixin:
     @require_vision
     @require_torch
     def test_pipeline_image_classification_fp16(self):
-        self.run_task_tests(task="image-classification", torch_dtype="float16")
+        self.run_task_tests(task="image-classification", dtype="float16")
 
     @is_pipeline_test
     @require_vision
@@ -585,7 +585,7 @@ class PipelineTesterMixin:
     @require_timm
     @require_torch
     def test_pipeline_image_segmentation_fp16(self):
-        self.run_task_tests(task="image-segmentation", torch_dtype="float16")
+        self.run_task_tests(task="image-segmentation", dtype="float16")
 
     @is_pipeline_test
     @require_vision
@@ -597,7 +597,7 @@ class PipelineTesterMixin:
     @require_vision
     @require_torch
     def test_pipeline_image_text_to_text_fp16(self):
-        self.run_task_tests(task="image-text-to-text", torch_dtype="float16")
+        self.run_task_tests(task="image-text-to-text", dtype="float16")
 
     @is_pipeline_test
     @require_vision
@@ -608,7 +608,7 @@ class PipelineTesterMixin:
     @require_vision
     @require_torch
     def test_pipeline_image_to_text_fp16(self):
-        self.run_task_tests(task="image-to-text", torch_dtype="float16")
+        self.run_task_tests(task="image-to-text", dtype="float16")
 
     @is_pipeline_test
     @require_timm
@@ -622,7 +622,7 @@ class PipelineTesterMixin:
     @require_vision
     @require_torch
     def test_pipeline_image_feature_extraction_fp16(self):
-        self.run_task_tests(task="image-feature-extraction", torch_dtype="float16")
+        self.run_task_tests(task="image-feature-extraction", dtype="float16")
 
     @unittest.skip(reason="`run_pipeline_test` is currently not implemented.")
     @is_pipeline_test
@@ -636,7 +636,7 @@ class PipelineTesterMixin:
     @require_vision
     @require_torch
     def test_pipeline_mask_generation_fp16(self):
-        self.run_task_tests(task="mask-generation", torch_dtype="float16")
+        self.run_task_tests(task="mask-generation", dtype="float16")
 
     @is_pipeline_test
     @require_vision
@@ -650,7 +650,7 @@ class PipelineTesterMixin:
     @require_timm
     @require_torch
     def test_pipeline_object_detection_fp16(self):
-        self.run_task_tests(task="object-detection", torch_dtype="float16")
+        self.run_task_tests(task="object-detection", dtype="float16")
 
     @is_pipeline_test
     def test_pipeline_question_answering(self):
@@ -659,7 +659,7 @@ class PipelineTesterMixin:
     @is_pipeline_test
     @require_torch
     def test_pipeline_question_answering_fp16(self):
-        self.run_task_tests(task="question-answering", torch_dtype="float16")
+        self.run_task_tests(task="question-answering", dtype="float16")
 
     @is_pipeline_test
     def test_pipeline_summarization(self):
@@ -668,7 +668,7 @@ class PipelineTesterMixin:
     @is_pipeline_test
     @require_torch
     def test_pipeline_summarization_fp16(self):
-        self.run_task_tests(task="summarization", torch_dtype="float16")
+        self.run_task_tests(task="summarization", dtype="float16")
 
     @is_pipeline_test
     def test_pipeline_table_question_answering(self):
@@ -677,7 +677,7 @@ class PipelineTesterMixin:
     @is_pipeline_test
     @require_torch
     def test_pipeline_table_question_answering_fp16(self):
-        self.run_task_tests(task="table-question-answering", torch_dtype="float16")
+        self.run_task_tests(task="table-question-answering", dtype="float16")
 
     @is_pipeline_test
     def test_pipeline_text2text_generation(self):
@@ -686,7 +686,7 @@ class PipelineTesterMixin:
     @is_pipeline_test
     @require_torch
     def test_pipeline_text2text_generation_fp16(self):
-        self.run_task_tests(task="text2text-generation", torch_dtype="float16")
+        self.run_task_tests(task="text2text-generation", dtype="float16")
 
     @is_pipeline_test
     def test_pipeline_text_classification(self):
@@ -695,7 +695,7 @@ class PipelineTesterMixin:
     @is_pipeline_test
     @require_torch
     def test_pipeline_text_classification_fp16(self):
-        self.run_task_tests(task="text-classification", torch_dtype="float16")
+        self.run_task_tests(task="text-classification", dtype="float16")
 
     @is_pipeline_test
     @require_torch_or_tf
@@ -705,7 +705,7 @@ class PipelineTesterMixin:
     @is_pipeline_test
     @require_torch
     def test_pipeline_text_generation_fp16(self):
-        self.run_task_tests(task="text-generation", torch_dtype="float16")
+        self.run_task_tests(task="text-generation", dtype="float16")
 
     @is_pipeline_test
     @require_torch
@@ -715,7 +715,7 @@ class PipelineTesterMixin:
     @is_pipeline_test
     @require_torch
     def test_pipeline_text_to_audio_fp16(self):
-        self.run_task_tests(task="text-to-audio", torch_dtype="float16")
+        self.run_task_tests(task="text-to-audio", dtype="float16")
 
     @is_pipeline_test
     def test_pipeline_token_classification(self):
@@ -724,7 +724,7 @@ class PipelineTesterMixin:
     @is_pipeline_test
     @require_torch
     def test_pipeline_token_classification_fp16(self):
-        self.run_task_tests(task="token-classification", torch_dtype="float16")
+        self.run_task_tests(task="token-classification", dtype="float16")
 
     @is_pipeline_test
     def test_pipeline_translation(self):
@@ -733,7 +733,7 @@ class PipelineTesterMixin:
     @is_pipeline_test
     @require_torch
     def test_pipeline_translation_fp16(self):
-        self.run_task_tests(task="translation", torch_dtype="float16")
+        self.run_task_tests(task="translation", dtype="float16")
 
     @is_pipeline_test
     @require_torch_or_tf
@@ -747,7 +747,7 @@ class PipelineTesterMixin:
     @require_torch
     @require_av
     def test_pipeline_video_classification_fp16(self):
-        self.run_task_tests(task="video-classification", torch_dtype="float16")
+        self.run_task_tests(task="video-classification", dtype="float16")
 
     @is_pipeline_test
     @require_torch
@@ -759,7 +759,7 @@ class PipelineTesterMixin:
     @require_torch
     @require_vision
     def test_pipeline_visual_question_answering_fp16(self):
-        self.run_task_tests(task="visual-question-answering", torch_dtype="float16")
+        self.run_task_tests(task="visual-question-answering", dtype="float16")
 
     @is_pipeline_test
     def test_pipeline_zero_shot(self):
@@ -768,7 +768,7 @@ class PipelineTesterMixin:
     @is_pipeline_test
     @require_torch
     def test_pipeline_zero_shot_fp16(self):
-        self.run_task_tests(task="zero-shot", torch_dtype="float16")
+        self.run_task_tests(task="zero-shot", dtype="float16")
 
     @is_pipeline_test
     @require_torch
@@ -778,7 +778,7 @@ class PipelineTesterMixin:
     @is_pipeline_test
     @require_torch
     def test_pipeline_zero_shot_audio_classification_fp16(self):
-        self.run_task_tests(task="zero-shot-audio-classification", torch_dtype="float16")
+        self.run_task_tests(task="zero-shot-audio-classification", dtype="float16")
 
     @is_pipeline_test
     @require_vision
@@ -789,7 +789,7 @@ class PipelineTesterMixin:
     @require_vision
     @require_torch
     def test_pipeline_zero_shot_image_classification_fp16(self):
-        self.run_task_tests(task="zero-shot-image-classification", torch_dtype="float16")
+        self.run_task_tests(task="zero-shot-image-classification", dtype="float16")
 
     @is_pipeline_test
     @require_vision
@@ -801,7 +801,7 @@ class PipelineTesterMixin:
     @require_vision
     @require_torch
     def test_pipeline_zero_shot_object_detection_fp16(self):
-        self.run_task_tests(task="zero-shot-object-detection", torch_dtype="float16")
+        self.run_task_tests(task="zero-shot-object-detection", dtype="float16")
 
     # This contains the test cases to be skipped without model architecture being involved.
     def is_pipeline_test_to_skip(
