@@ -18,7 +18,7 @@ import json
 import random
 import tempfile
 from pathlib import Path
-from typing import Optional
+from typing import Optional, Union
 
 import numpy as np
 from huggingface_hub import hf_hub_download
@@ -46,16 +46,16 @@ if is_torch_available():
 
 MODALITY_INPUT_DATA = {
     "images": [
-        "http://images.cocodataset.org/val2017/000000039769.jpg",
-        "http://images.cocodataset.org/val2017/000000039769.jpg",
+        "https://huggingface.co/datasets/huggingface/documentation-images/resolve/main/coco_sample.png",
+        "https://huggingface.co/datasets/huggingface/documentation-images/resolve/main/coco_sample.png",
     ],
     "videos": [
-        "https://test-videos.co.uk/vids/bigbuckbunny/mp4/h264/720/Big_Buck_Bunny_720_10s_10MB.mp4",
-        ["https://www.ilankelman.org/stopsigns/australia.jpg", "https://www.ilankelman.org/stopsigns/australia.jpg"],
+        "https://huggingface.co/datasets/raushan-testing-hf/videos-test/resolve/main/Big_Buck_Bunny_720_10s_10MB.mp4",
+        "https://huggingface.co/datasets/raushan-testing-hf/videos-test/resolve/main/sample_demo_1.mp4",
     ],
     "audio": [
-        "https://qianwen-res.oss-cn-beijing.aliyuncs.com/Qwen2-Audio/audio/glass-breaking-151256.mp3",
-        "https://qianwen-res.oss-cn-beijing.aliyuncs.com/Qwen2-Audio/audio/f2641_0_throatclearing.wav",
+        "https://huggingface.co/datasets/raushan-testing-hf/audio-test/resolve/main/glass-breaking-151256.mp3",
+        "https://huggingface.co/datasets/raushan-testing-hf/audio-test/resolve/main/f2641_0_throatclearing.wav",
     ],
 }
 
@@ -63,7 +63,9 @@ if is_av_available():
     from transformers.video_utils import load_video
 
     # load a video file in memory for testing
-    video, _ = load_video("https://test-videos.co.uk/vids/bigbuckbunny/mp4/h264/720/Big_Buck_Bunny_720_10s_10MB.mp4")
+    video, _ = load_video(
+        "https://huggingface.co/datasets/raushan-testing-hf/videos-test/resolve/main/Big_Buck_Bunny_720_10s_10MB.mp4"
+    )
     MODALITY_INPUT_DATA["videos"].append(video)
 
 
@@ -134,11 +136,14 @@ class ProcessorTesterMixin:
         processor = self.processor_class(**components, **self.prepare_processor_dict())
         return processor
 
-    def prepare_text_inputs(self, batch_size: Optional[int] = None, modality: Optional[str] = None):
-        if modality is not None:
-            special_token_to_add = getattr(self, f"{modality}_token", "")
-        else:
-            special_token_to_add = ""
+    def prepare_text_inputs(self, batch_size: Optional[int] = None, modalities: Optional[Union[str, list]] = None):
+        if isinstance(modalities, str):
+            modalities = [modalities]
+
+        special_token_to_add = ""
+        if modalities is not None:
+            for modality in modalities:
+                special_token_to_add += getattr(self, f"{modality}_token", "")
 
         if batch_size is None:
             return f"lower newer {special_token_to_add}"
@@ -169,6 +174,14 @@ class ProcessorTesterMixin:
             return video_input
         return [video_input] * batch_size
 
+    def prepare_audio_inputs(self, batch_size: Optional[int] = None):
+        """This function prepares a list of numpy audio."""
+        raw_speech = floats_list((1, 1000))
+        raw_speech = [np.asarray(audio) for audio in raw_speech]
+        if batch_size is None:
+            return raw_speech
+        return raw_speech * batch_size
+
     def test_processor_to_json_string(self):
         processor = self.get_processor()
         obj = json.loads(processor.to_json_string())
@@ -204,6 +217,53 @@ class ProcessorTesterMixin:
                     if "tokenizer" not in attribute:
                         self.assertEqual(repr(attribute_first), repr(attribute_second))
 
+    def test_processor_from_and_save_pretrained_as_nested_dict(self):
+        processor_first = self.get_processor()
+
+        with tempfile.TemporaryDirectory() as tmpdirname:
+            # Save with `legacy_serialization=False` so that all attrbiutes are saved in one json file
+            saved_files = processor_first.save_pretrained(tmpdirname, legacy_serialization=False)
+            check_json_file_has_correct_format(saved_files[0])
+
+            # Load it back and check if loaded correctly
+            processor_second = self.processor_class.from_pretrained(tmpdirname)
+            self.assertEqual(processor_second.to_dict(), processor_first.to_dict())
+
+            # Try to load each attribute separately from saved directory
+            for attribute in processor_first.attributes:
+                attribute_class_name = getattr(processor_first, f"{attribute}_class")
+                if isinstance(attribute_class_name, tuple):
+                    if attribute == "image_processor":
+                        # TODO: @yoni, change logic in v4.52 (when use_fast set to True by default)
+                        attribute_class_name = attribute_class_name[0]
+                    else:
+                        attribute_class_name = attribute_class_name[-1]
+
+                attribute_class = processor_class_from_name(attribute_class_name)
+                attribute_reloaded = attribute_class.from_pretrained(tmpdirname)
+                attribute_first = getattr(processor_first, attribute)
+
+                # tokenizer repr contains model-path from where we loaded
+                if "tokenizer" not in attribute:
+                    self.assertEqual(repr(attribute_first), repr(attribute_reloaded))
+
+    def test_model_input_names(self):
+        processor = self.get_processor()
+
+        text = self.prepare_text_inputs(modalities=["image", "video", "audio"])
+        image_input = self.prepare_image_inputs()
+        video_inputs = self.prepare_video_inputs()
+        audio_inputs = self.prepare_audio_inputs()
+        inputs_dict = {"text": text, "images": image_input, "videos": video_inputs, "audio": audio_inputs}
+
+        call_signature = inspect.signature(processor.__call__)
+        input_args = [param.name for param in call_signature.parameters.values()]
+        inputs_dict = {k: v for k, v in inputs_dict.items() if k in input_args}
+
+        inputs = processor(**inputs_dict, return_tensors="pt")
+
+        self.assertSetEqual(set(inputs.keys()), set(processor.model_input_names))
+
     # These kwargs-related tests ensure that processors are correctly instantiated.
     # they need to be applied only if an image_processor exists.
 
@@ -229,7 +289,7 @@ class ProcessorTesterMixin:
 
         processor = self.processor_class(**processor_components, **processor_kwargs)
         self.skip_processor_without_typed_kwargs(processor)
-        input_str = self.prepare_text_inputs(modality="image")
+        input_str = self.prepare_text_inputs(modalities="image")
         image_input = self.prepare_image_inputs()
         inputs = processor(text=input_str, images=image_input, return_tensors="pt")
         self.assertEqual(inputs[self.text_input_name].shape[-1], 117)
@@ -252,7 +312,7 @@ class ProcessorTesterMixin:
         processor = self.processor_class(**processor_components, **processor_kwargs)
         self.skip_processor_without_typed_kwargs(processor)
 
-        input_str = self.prepare_text_inputs(modality="image")
+        input_str = self.prepare_text_inputs(modalities="image")
         image_input = self.prepare_image_inputs()
 
         inputs = processor(text=input_str, images=image_input, return_tensors="pt")
@@ -267,7 +327,7 @@ class ProcessorTesterMixin:
 
         processor = self.processor_class(**processor_components, **processor_kwargs)
         self.skip_processor_without_typed_kwargs(processor)
-        input_str = self.prepare_text_inputs(modality="image")
+        input_str = self.prepare_text_inputs(modalities="image")
         image_input = self.prepare_image_inputs()
         inputs = processor(
             text=input_str, images=image_input, return_tensors="pt", max_length=112, padding="max_length"
@@ -287,7 +347,7 @@ class ProcessorTesterMixin:
         processor = self.processor_class(**processor_components, **processor_kwargs)
         self.skip_processor_without_typed_kwargs(processor)
 
-        input_str = self.prepare_text_inputs(modality="image")
+        input_str = self.prepare_text_inputs(modalities="image")
         image_input = self.prepare_image_inputs()
 
         inputs = processor(text=input_str, images=image_input, do_rescale=True, rescale_factor=-1, return_tensors="pt")
@@ -301,7 +361,7 @@ class ProcessorTesterMixin:
         processor = self.processor_class(**processor_components, **processor_kwargs)
         self.skip_processor_without_typed_kwargs(processor)
 
-        input_str = self.prepare_text_inputs(modality="image")
+        input_str = self.prepare_text_inputs(modalities="image")
         image_input = self.prepare_image_inputs()
         inputs = processor(
             text=input_str,
@@ -324,7 +384,7 @@ class ProcessorTesterMixin:
         processor = self.processor_class(**processor_components, **processor_kwargs)
         self.skip_processor_without_typed_kwargs(processor)
 
-        input_str = self.prepare_text_inputs(batch_size=2, modality="image")
+        input_str = self.prepare_text_inputs(batch_size=2, modalities="image")
         image_input = self.prepare_image_inputs(batch_size=2)
         inputs = processor(
             text=input_str,
@@ -350,7 +410,7 @@ class ProcessorTesterMixin:
         processor = self.processor_class(**processor_components, **processor_kwargs)
         self.skip_processor_without_typed_kwargs(processor)
 
-        input_str = [self.prepare_text_inputs(modality="image")]
+        input_str = [self.prepare_text_inputs(modalities="image")]
         image_input = self.prepare_image_inputs()
         with self.assertRaises(ValueError):
             _ = processor(
@@ -381,7 +441,7 @@ class ProcessorTesterMixin:
         processor = self.processor_class(**processor_components, **processor_kwargs)
         self.skip_processor_without_typed_kwargs(processor)
 
-        input_str = self.prepare_text_inputs(modality="image")
+        input_str = self.prepare_text_inputs(modalities="image")
         image_input = self.prepare_image_inputs()
 
         # Define the kwargs for each modality
@@ -404,7 +464,7 @@ class ProcessorTesterMixin:
         processor_kwargs = self.prepare_processor_dict()
         processor = self.processor_class(**processor_components, **processor_kwargs)
         self.skip_processor_without_typed_kwargs(processor)
-        input_str = self.prepare_text_inputs(modality="image")
+        input_str = self.prepare_text_inputs(modalities="image")
         image_input = self.prepare_image_inputs()
 
         # Define the kwargs for each modality
@@ -431,9 +491,8 @@ class ProcessorTesterMixin:
         processor = self.processor_class(tokenizer=tokenizer, feature_extractor=feature_extractor, **processor_kwargs)
         self.skip_processor_without_typed_kwargs(processor)
 
-        input_str = self.prepare_text_inputs(batch_size=3, modality="audio")
-        raw_speech = floats_list((3, 1000))
-        raw_speech = [np.asarray(audio) for audio in raw_speech]
+        input_str = self.prepare_text_inputs(batch_size=3, modalities="audio")
+        raw_speech = self.prepare_audio_inputs(batch_size=3)
         inputs = processor(text=input_str, audio=raw_speech, return_tensors="pt")
         self.assertEqual(len(inputs[self.text_input_name][0]), 300)
 
@@ -449,9 +508,8 @@ class ProcessorTesterMixin:
         processor = self.processor_class(tokenizer=tokenizer, feature_extractor=feature_extractor, **processor_kwargs)
         self.skip_processor_without_typed_kwargs(processor)
 
-        input_str = self.prepare_text_inputs(batch_size=3, modality="audio")
-        raw_speech = floats_list((3, 1000))
-        raw_speech = [np.asarray(audio) for audio in raw_speech]
+        input_str = self.prepare_text_inputs(batch_size=3, modalities="audio")
+        raw_speech = self.prepare_audio_inputs(batch_size=3)
         inputs = processor(text=input_str, audio=raw_speech, return_tensors="pt", max_length=300, padding="max_length")
 
         self.assertEqual(len(inputs[self.text_input_name][0]), 300)
@@ -468,9 +526,8 @@ class ProcessorTesterMixin:
         processor = self.processor_class(tokenizer=tokenizer, feature_extractor=feature_extractor, **processor_kwargs)
         self.skip_processor_without_typed_kwargs(processor)
 
-        input_str = self.prepare_text_inputs(batch_size=3, modality="audio")
-        raw_speech = floats_list((3, 1000))
-        raw_speech = [np.asarray(audio) for audio in raw_speech]
+        input_str = self.prepare_text_inputs(batch_size=3, modalities="audio")
+        raw_speech = self.prepare_audio_inputs(batch_size=3)
         inputs = processor(text=input_str, audio=raw_speech, return_tensors="pt", max_length=300, padding="max_length")
 
         self.assertEqual(len(inputs[self.text_input_name][0]), 300)
@@ -487,9 +544,8 @@ class ProcessorTesterMixin:
         processor = self.processor_class(tokenizer=tokenizer, feature_extractor=feature_extractor, **processor_kwargs)
         self.skip_processor_without_typed_kwargs(processor)
 
-        input_str = self.prepare_text_inputs(batch_size=3, modality="audio")
-        raw_speech = floats_list((3, 1000))
-        raw_speech = [np.asarray(audio) for audio in raw_speech]
+        input_str = self.prepare_text_inputs(batch_size=3, modalities="audio")
+        raw_speech = self.prepare_audio_inputs(batch_size=3)
         with self.assertRaises(ValueError):
             _ = processor(
                 text=input_str,
@@ -511,9 +567,8 @@ class ProcessorTesterMixin:
         processor = self.processor_class(tokenizer=tokenizer, feature_extractor=feature_extractor, **processor_kwargs)
         self.skip_processor_without_typed_kwargs(processor)
 
-        input_str = self.prepare_text_inputs(batch_size=3, modality="audio")
-        raw_speech = floats_list((3, 1000))
-        raw_speech = [np.asarray(audio) for audio in raw_speech]
+        input_str = self.prepare_text_inputs(batch_size=3, modalities="audio")
+        raw_speech = self.prepare_audio_inputs(batch_size=3)
 
         # Define the kwargs for each modality
         all_kwargs = {
@@ -534,9 +589,9 @@ class ProcessorTesterMixin:
 
         processor = self.processor_class(**processor_components, **processor_kwargs)
         self.skip_processor_without_typed_kwargs(processor)
-        input_str = self.prepare_text_inputs(modality="video")
+        input_str = self.prepare_text_inputs(modalities="video")
         video_input = self.prepare_video_inputs()
-        inputs = processor(text=input_str, videos=video_input, return_tensors="pt")
+        inputs = processor(text=input_str, videos=video_input, do_sample_frames=False, return_tensors="pt")
         self.assertEqual(inputs[self.text_input_name].shape[-1], 167)
 
     def test_video_processor_defaults_preserved_by_video_kwargs(self):
@@ -557,10 +612,10 @@ class ProcessorTesterMixin:
         processor = self.processor_class(**processor_components, **processor_kwargs)
         self.skip_processor_without_typed_kwargs(processor)
 
-        input_str = self.prepare_text_inputs(modality="video")
+        input_str = self.prepare_text_inputs(modalities="video")
         video_input = self.prepare_video_inputs()
 
-        inputs = processor(text=input_str, videos=video_input, return_tensors="pt")
+        inputs = processor(text=input_str, videos=video_input, do_sample_frames=False, return_tensors="pt")
         self.assertLessEqual(inputs[self.videos_input_name][0].mean(), 0)
 
     def test_kwargs_overrides_default_tokenizer_kwargs_video(self):
@@ -572,10 +627,15 @@ class ProcessorTesterMixin:
 
         processor = self.processor_class(**processor_components, **processor_kwargs)
         self.skip_processor_without_typed_kwargs(processor)
-        input_str = self.prepare_text_inputs(modality="video")
+        input_str = self.prepare_text_inputs(modalities="video")
         video_input = self.prepare_video_inputs()
         inputs = processor(
-            text=input_str, videos=video_input, return_tensors="pt", max_length=162, padding="max_length"
+            text=input_str,
+            videos=video_input,
+            do_sample_frames=False,
+            return_tensors="pt",
+            max_length=162,
+            padding="max_length",
         )
         self.assertEqual(inputs[self.text_input_name].shape[-1], 162)
 
@@ -592,10 +652,17 @@ class ProcessorTesterMixin:
         processor = self.processor_class(**processor_components, **processor_kwargs)
         self.skip_processor_without_typed_kwargs(processor)
 
-        input_str = self.prepare_text_inputs(modality="video")
+        input_str = self.prepare_text_inputs(modalities="video")
         video_input = self.prepare_video_inputs()
 
-        inputs = processor(text=input_str, videos=video_input, do_rescale=True, rescale_factor=-1, return_tensors="pt")
+        inputs = processor(
+            text=input_str,
+            videos=video_input,
+            do_sample_frames=False,
+            do_rescale=True,
+            rescale_factor=-1,
+            return_tensors="pt",
+        )
         self.assertLessEqual(inputs[self.videos_input_name][0].mean(), 0)
 
     def test_unstructured_kwargs_video(self):
@@ -606,11 +673,12 @@ class ProcessorTesterMixin:
         processor = self.processor_class(**processor_components, **processor_kwargs)
         self.skip_processor_without_typed_kwargs(processor)
 
-        input_str = self.prepare_text_inputs(modality="video")
+        input_str = self.prepare_text_inputs(modalities="video")
         video_input = self.prepare_video_inputs()
         inputs = processor(
             text=input_str,
             videos=video_input,
+            do_sample_frames=False,
             return_tensors="pt",
             do_rescale=True,
             rescale_factor=-1,
@@ -629,11 +697,12 @@ class ProcessorTesterMixin:
         processor = self.processor_class(**processor_components, **processor_kwargs)
         self.skip_processor_without_typed_kwargs(processor)
 
-        input_str = self.prepare_text_inputs(batch_size=2, modality="video")
+        input_str = self.prepare_text_inputs(batch_size=2, modalities="video")
         video_input = self.prepare_video_inputs(batch_size=2)
         inputs = processor(
             text=input_str,
             videos=video_input,
+            do_sample_frames=False,
             return_tensors="pt",
             do_rescale=True,
             rescale_factor=-1,
@@ -655,12 +724,13 @@ class ProcessorTesterMixin:
         processor = self.processor_class(**processor_components, **processor_kwargs)
         self.skip_processor_without_typed_kwargs(processor)
 
-        input_str = [self.prepare_text_inputs(modality="video")]
+        input_str = [self.prepare_text_inputs(modalities="video")]
         video_input = self.prepare_video_inputs()
         with self.assertRaises(ValueError):
             _ = processor(
                 text=input_str,
                 videos=video_input,
+                do_sample_frames=False,
                 videos_kwargs={"do_rescale": True, "rescale_factor": -1},
                 do_rescale=True,
                 return_tensors="pt",
@@ -674,13 +744,13 @@ class ProcessorTesterMixin:
         processor = self.processor_class(**processor_components, **processor_kwargs)
         self.skip_processor_without_typed_kwargs(processor)
 
-        input_str = self.prepare_text_inputs(modality="video")
+        input_str = self.prepare_text_inputs(modalities="video")
         video_input = self.prepare_video_inputs()
 
         # Define the kwargs for each modality
         all_kwargs = {
             "common_kwargs": {"return_tensors": "pt"},
-            "videos_kwargs": {"do_rescale": True, "rescale_factor": -1},
+            "videos_kwargs": {"do_rescale": True, "rescale_factor": -1, "do_sample_frames": False},
             "text_kwargs": {"padding": "max_length", "max_length": 176},
         }
 
@@ -697,13 +767,13 @@ class ProcessorTesterMixin:
         processor_kwargs = self.prepare_processor_dict()
         processor = self.processor_class(**processor_components, **processor_kwargs)
         self.skip_processor_without_typed_kwargs(processor)
-        input_str = self.prepare_text_inputs(modality="video")
+        input_str = self.prepare_text_inputs(modalities="video")
         video_input = self.prepare_video_inputs()
 
         # Define the kwargs for each modality
         all_kwargs = {
             "common_kwargs": {"return_tensors": "pt"},
-            "videos_kwargs": {"do_rescale": True, "rescale_factor": -1},
+            "videos_kwargs": {"do_rescale": True, "rescale_factor": -1, "do_sample_frames": False},
             "text_kwargs": {"padding": "max_length", "max_length": 176},
         }
 
@@ -721,7 +791,7 @@ class ProcessorTesterMixin:
         processor = self.processor_class(**processor_components)
         self.skip_processor_without_typed_kwargs(processor)
 
-        input_str = self.prepare_text_inputs(modality="image")
+        input_str = self.prepare_text_inputs(modalities="image")
         image_input = self.prepare_image_inputs()
 
         with self.assertRaises(ValueError):
@@ -746,7 +816,7 @@ class ProcessorTesterMixin:
         processor = self.processor_class(**processor_components, **processor_kwargs)
         self.skip_processor_without_typed_kwargs(processor)
 
-        input_str = self.prepare_text_inputs(batch_size=3, modality="audio")
+        input_str = self.prepare_text_inputs(batch_size=3, modalities="audio")
         audio_lengths = [4000, 8000, 16000, 32000]
         raw_speech = [np.asarray(audio)[:length] for audio, length in zip(floats_list((3, 32_000)), audio_lengths)]
 
@@ -933,11 +1003,11 @@ class ProcessorTesterMixin:
     @parameterized.expand([(1, "np"), (1, "pt"), (2, "np"), (2, "pt")])
     def test_apply_chat_template_audio(self, batch_size: int, return_tensors: str):
         self._test_apply_chat_template(
-            "audio", batch_size, return_tensors, "audio_input_name", "feature_extracttor", MODALITY_INPUT_DATA["audio"]
+            "audio", batch_size, return_tensors, "audio_input_name", "feature_extractor", MODALITY_INPUT_DATA["audio"]
         )
 
     @require_av
-    @parameterized.expand([(1, "pt"), (2, "pt"), (3, "pt")])  # video processor supports only torchvision
+    @parameterized.expand([(1, "pt"), (2, "pt")])  # video processor supports only torchvision
     def test_apply_chat_template_video(self, batch_size: int, return_tensors: str):
         self._test_apply_chat_template(
             "video", batch_size, return_tensors, "videos_input_name", "video_processor", MODALITY_INPUT_DATA["videos"]
@@ -1042,8 +1112,8 @@ class ProcessorTesterMixin:
         self.assertEqual(len(out_dict_with_video[self.videos_input_name]), 1)
         self.assertEqual(len(out_dict_with_video[self.videos_input_name][0]), 300)
 
-        # Load video as a list of frames (i.e. images). NOTE: each frame should have same size
-        # because we assume they come from one video
+        # Load video as a list of frames (i.e. images).
+        # NOTE: each frame should have same size because we assume they come from one video
         messages[0][0]["content"][0] = {
             "type": "video",
             "url": [
@@ -1061,6 +1131,19 @@ class ProcessorTesterMixin:
         self.assertEqual(len(out_dict_with_video[self.videos_input_name]), 1)
         self.assertEqual(len(out_dict_with_video[self.videos_input_name][0]), 2)
 
+        # When the inputs are frame URLs/paths we expect that those are already
+        # sampled and will raise an error is asked to sample again.
+        with self.assertRaisesRegex(
+            ValueError, "Sampling frames from a list of images is not supported! Set `do_sample_frames=False`"
+        ):
+            out_dict_with_video = processor.apply_chat_template(
+                messages,
+                add_generation_prompt=True,
+                tokenize=True,
+                return_dict=True,
+                do_sample_frames=True,
+            )
+
     @require_librosa
     @require_av
     def test_chat_template_audio_from_video(self):
