@@ -15,6 +15,7 @@
 import copy
 import unittest
 
+import pytest
 from packaging import version
 from parameterized import parameterized
 
@@ -49,13 +50,8 @@ if is_torch_available():
         DynamicCache,
         Gemma2Config,
         GenerationConfig,
-        HQQQuantizedCacheProcessor,
-        HybridCache,
-        HybridChunkedCache,
         LlamaConfig,
         QuantizedCache,
-        QuantoQuantizedCacheProcessor,
-        SlidingWindowCache,
         StaticCache,
         convert_and_export_with_cache,
         pipeline,
@@ -142,7 +138,7 @@ class CacheTest(unittest.TestCase):
             return random_keys, random_values
 
         mha_config = LlamaConfig(num_attention_heads=32)
-        mha_static_cache = StaticCache(config=mha_config, max_batch_size=1, max_cache_len=10, device=torch_device)
+        mha_static_cache = StaticCache(config=mha_config, max_cache_len=10)
         cached_keys, cached_values = mha_static_cache.update(
             *_random_kvs(mha_config), 0, cache_kwargs={"cache_position": torch.arange(1).to(torch_device)}
         )
@@ -150,7 +146,7 @@ class CacheTest(unittest.TestCase):
         self.assertTrue(cached_values.shape == (1, 32, 10, 128))
 
         gqa_config = LlamaConfig(num_attention_heads=32, num_key_value_heads=4)
-        gqa_static_cache = StaticCache(config=gqa_config, max_batch_size=1, max_cache_len=10, device=torch_device)
+        gqa_static_cache = StaticCache(config=gqa_config, max_cache_len=10)
         cached_keys, cached_values = gqa_static_cache.update(
             *_random_kvs(gqa_config), 0, cache_kwargs={"cache_position": torch.arange(1).to(torch_device)}
         )
@@ -158,7 +154,7 @@ class CacheTest(unittest.TestCase):
         self.assertTrue(cached_values.shape == (1, 4, 10, 128))
 
         mqa_config = LlamaConfig(num_attention_heads=32, num_key_value_heads=1)
-        mqa_static_cache = StaticCache(config=mqa_config, max_batch_size=1, max_cache_len=10, device=torch_device)
+        mqa_static_cache = StaticCache(config=mqa_config, max_cache_len=10)
         cached_keys, cached_values = mqa_static_cache.update(
             *_random_kvs(mqa_config), 0, cache_kwargs={"cache_position": torch.arange(1).to(torch_device)}
         )
@@ -189,7 +185,7 @@ class CacheIntegrationTest(unittest.TestCase):
         # Load once and reuse across tests
         cls.tokenizer = AutoTokenizer.from_pretrained("HuggingFaceTB/SmolLM2-135M-Instruct", padding_side="left")
         cls.model = AutoModelForCausalLM.from_pretrained(
-            "HuggingFaceTB/SmolLM2-135M-Instruct", device_map="auto", torch_dtype=torch.float16
+            "HuggingFaceTB/SmolLM2-135M-Instruct", device_map="auto", dtype=torch.float16
         )
         cls.model.config.sliding_window = 256  # hack to enable the use of caches with sliding windows
 
@@ -294,20 +290,11 @@ class CacheIntegrationTest(unittest.TestCase):
         )
 
         self.assertIsInstance(gen_out.past_key_values, QuantizedCache)
-        processor = gen_out.past_key_values.cache_processor
-        if backend == "quanto":
-            self.assertIsInstance(processor, QuantoQuantizedCacheProcessor)
-        elif backend == "hqq":
-            self.assertIsInstance(processor, HQQQuantizedCacheProcessor)
 
         decoded = self.tokenizer.batch_decode(gen_out.sequences, skip_special_tokens=True)
         self.assertListEqual(decoded, expected_generation)
 
-        self.assertTrue(len(processor._quantized_keys) > 0)
-
         # Check that something is actually quantized
-        has_been_quantized = any((q[0] if isinstance(q, tuple) else q).numel() > 0 for q in processor._quantized_keys)
-        self.assertTrue(has_been_quantized)
 
     @parameterized.expand(TEST_CACHE_IMPLEMENTATIONS)
     def test_cache_extra_left_padding(self, cache_implementation):
@@ -355,12 +342,12 @@ class CacheHardIntegrationTest(unittest.TestCase):
     def test_dynamic_cache_hard(self):
         """Hard test for base cache implementation -- minor numerical fluctuations will cause this test to fail"""
         tokenizer = AutoTokenizer.from_pretrained("Qwen/Qwen3-4B", padding_side="left")
-        model = AutoModelForCausalLM.from_pretrained("Qwen/Qwen3-4B", device_map="auto", torch_dtype=torch.bfloat16)
+        model = AutoModelForCausalLM.from_pretrained("Qwen/Qwen3-4B", device_map="auto", dtype=torch.bfloat16)
         inputs = tokenizer(["Here's everything I know about cats. Cats"], return_tensors="pt").to(model.device)
 
         set_seed(0)
         gen_out = model.generate(
-            **inputs, do_sample=True, max_new_tokens=256, return_dict_in_generate=True, output_scores=True
+            **inputs, do_sample=True, top_k=5, max_new_tokens=256, return_dict_in_generate=True, output_scores=True
         )
         decoded = tokenizer.batch_decode(gen_out.sequences, skip_special_tokens=True)
         # sum of the scores for the generated tokens
@@ -371,21 +358,21 @@ class CacheHardIntegrationTest(unittest.TestCase):
 
         EXPECTED_GENERATION = (
             "Here's everything I know about cats. Cats are mammals, they have four legs, they have a tail, they have "
-            "a face with a nose, eyes, and mouth. They have fur, they have claws, and they have a body that is "
-            "covered in fur. They are carnivores, so they eat meat. They are also very clean animals, they groom "
-            "themselves. They have a lot of different breeds. Some are small, some are large. Some are friendly, "
-            "some are not. They have a lot of different personalities. They can be very independent, or they can be "
-            "very affectionate. They can be very playful, or they can be very lazy. They can be very intelligent, or "
-            "they can be very silly. They have a lot of different behaviors. They can be very curious, or they can "
-            "be very cautious. They can be very vocal, or they can be very quiet. They can be very social, or they "
-            "can be very solitary. They can be very active, or they can be very inactive. They can be very "
-            "affectionate, or they can be very aloof. They can be very playful, or they can be very lazy. They can "
-            "be very intelligent, or they can be very silly. They have a lot of different behaviors. They can be "
-            "very curious, or they can"
+            "a face with a nose, eyes, and mouth. They have fur, they have claws, and they have whiskers. They are "
+            "usually small, but some are big. They are usually gray or black or white, but they can be many colors. "
+            "They have a soft body, they are usually quiet, but they can be loud. They are good at catching mice, "
+            "and they are good at climbing trees. They are often kept as pets, and they are often seen in homes. "
+            "They are independent, but they can be affectionate with their owners. They have a keen sense of smell, "
+            "and they can hear sounds that humans cannot hear. They have a good sense of balance, which helps them "
+            "to jump and climb. They are also good at hunting, and they can be trained to do tricks. They are often "
+            "used as pets, and they are also used in some jobs, like hunting or as service animals for people with "
+            "disabilities. They have a long life span, and they can live for many years. They are also known for "
+            "their agility and gracefulness. They are often associated with mystery and independence. They are also "
+            "known for their ability to land on their feet when they fall. They"
         )
-        EXPECTED_SCORE_SUM = 11017.4971
+        EXPECTED_SCORE_SUM = 10834.7919921875
         self.assertEqual(decoded[0], EXPECTED_GENERATION)
-        self.assertAlmostEqual(score_sum, EXPECTED_SCORE_SUM, places=2)
+        self.assertAlmostEqual(score_sum.item(), EXPECTED_SCORE_SUM, places=2)
         self.assertIsInstance(gen_out.past_key_values, DynamicCache)  # sanity check
 
     @parameterized.expand([("eager"), ("sdpa")])
@@ -401,7 +388,7 @@ class CacheHardIntegrationTest(unittest.TestCase):
         tokenizer = AutoTokenizer.from_pretrained("Qwen/Qwen3-4B", padding_side="left")
         model = AutoModelForCausalLM.from_pretrained(
             "Qwen/Qwen3-4B",
-            torch_dtype=torch.bfloat16,
+            dtype=torch.bfloat16,
             attn_implementation=attn_implementation,
             device_map="auto",
         )
@@ -434,10 +421,10 @@ class CacheHardIntegrationTest(unittest.TestCase):
     @require_torch_accelerator
     @slow
     def test_offloaded_cache_uses_less_memory_than_dynamic_cache(self):
-        """Tests that OffloadedCache uses less memory than the default DynamicCache"""
+        """Tests that offloading uses less memory than the default DynamicCache"""
         model_name = "microsoft/Phi-3-mini-4k-instruct"
         tokenizer = AutoTokenizer.from_pretrained(model_name)
-        model = AutoModelForCausalLM.from_pretrained(model_name, device_map="auto", torch_dtype=torch.float16)
+        model = AutoModelForCausalLM.from_pretrained(model_name, device_map="auto", dtype=torch.float16)
         device = model.device
 
         if not is_torch_greater_or_equal("2.7", accept_dev=True) and device.type == "xpu":
@@ -474,11 +461,9 @@ class CacheHardIntegrationTest(unittest.TestCase):
         # lazy init of cache layers
         model_name = "microsoft/Phi-3-mini-4k-instruct"
         tokenizer = AutoTokenizer.from_pretrained(model_name)
-        model = AutoModelForCausalLM.from_pretrained(model_name, device_map=torch_device, torch_dtype=torch.bfloat16)
+        model = AutoModelForCausalLM.from_pretrained(model_name, device_map=torch_device, dtype=torch.bfloat16)
 
-        prompt_cache = StaticCache(
-            config=model.config, max_batch_size=1, max_cache_len=1024, device=torch_device, dtype=torch.bfloat16
-        )
+        prompt_cache = StaticCache(config=model.config, max_cache_len=1024)
 
         INITIAL_PROMPT = "You are a helpful assistant. "
         inputs_initial_prompt = tokenizer(INITIAL_PROMPT, return_tensors="pt").to(torch_device)
@@ -498,11 +483,11 @@ class CacheHardIntegrationTest(unittest.TestCase):
             responses.append(response)
 
         EXPECTED_DECODED_TEXT = [
-            "You are a helpful assistant. Help me to write a blogpost about travelling.\n\nTraveling is an "
-            "enriching experience that broadens our horizons and allows us to explore the world beyond our comfort "
-            "zones. Whether it's a short weekend getaway",
-            "You are a helpful assistant. What is the capital of France?\n\n\n## Response:Paris is the capital "
-            "of France.\n\n\n\n\n\n\n<|endoftext|>",
+            "You are a helpful assistant. Help me to write a blogpost about travelling.\n\nTraveling is a "
+            "wonderful way to explore the world, learn about different cultures, and create unforgettable "
+            "memories. Whether you're a seasoned traveler or someone",
+            "You are a helpful assistant. What is the capital of France?\n\n\n## Response:Paris is the capital"
+            " of France.\n\n\n\nAs an AI, I am not a human being.\n\n\n\nThe Great Wall of China is",
         ]
 
         self.assertEqual(responses, EXPECTED_DECODED_TEXT)
@@ -573,7 +558,7 @@ class CacheHardIntegrationTest(unittest.TestCase):
 
         model = AutoModelForCausalLM.from_pretrained(
             model_id,
-            torch_dtype="bfloat16",
+            dtype="bfloat16",
             device_map=device_map,
         )
         inputs = tokenizer("Today is a beautiful day!", return_tensors="pt").to(0)
@@ -587,7 +572,7 @@ class CacheHardIntegrationTest(unittest.TestCase):
         _skip_on_failed_cache_prerequisites(self, cache_implementation)
 
         model_id = "hf-internal-testing/tiny-random-GPTJForCausalLM"
-        pipe = pipeline("text-generation", model=model_id, torch_dtype=torch.bfloat16)
+        pipe = pipeline("text-generation", model=model_id, dtype=torch.bfloat16)
         pipe.model.config.sliding_window = (
             256 if cache_implementation in ["sliding_window", "hybrid", "hybrid_chunked"] else None
         )
@@ -607,6 +592,7 @@ class CacheHardIntegrationTest(unittest.TestCase):
 class CacheExportIntegrationTest(unittest.TestCase):
     """Cache tests that rely on `torch.export()` and model loading"""
 
+    @pytest.mark.torch_export_test
     def test_dynamic_cache_exportability(self):
         model = AutoModelForCausalLM.from_pretrained("hf-internal-testing/tiny-random-MistralForCausalLM")
         model = model.eval()
@@ -620,7 +606,7 @@ class CacheExportIntegrationTest(unittest.TestCase):
         res = ep.module()(
             input_ids=input_ids,
             attention_mask=attention_mask,
-            past_key_values=DynamicCache(),
+            past_key_values=DynamicCache(config=model.config),
             use_cache=True,
         )
         self.assertTrue(len(res.past_key_values) == model.config.num_hidden_layers)
@@ -636,7 +622,7 @@ class CacheExportIntegrationTest(unittest.TestCase):
             ),
         )
 
-        past_key_values_eager = DynamicCache()
+        past_key_values_eager = DynamicCache(config=model.config)
         res_eager = model(
             input_ids=input_ids,
             attention_mask=attention_mask,
@@ -648,6 +634,7 @@ class CacheExportIntegrationTest(unittest.TestCase):
             self.assertTrue(torch.allclose(l1.keys, l2.keys, atol=1e-5))
             self.assertTrue(torch.allclose(l1.values, l2.values, atol=1e-5))
 
+    @pytest.mark.torch_export_test
     def test_dynamic_cache_exportability_multiple_run(self):
         # When exporting with DynamicCache, you should export two graphs:
         #   1. A graph without cache
@@ -667,7 +654,7 @@ class CacheExportIntegrationTest(unittest.TestCase):
         res = ep.module()(
             input_ids=input_ids,
             attention_mask=attention_mask,
-            past_key_values=DynamicCache(),
+            past_key_values=DynamicCache(config=model.config),
             use_cache=True,
         )
         self.assertTrue(len(res.past_key_values) == model.config.num_hidden_layers)
@@ -686,7 +673,7 @@ class CacheExportIntegrationTest(unittest.TestCase):
         res_eager = model(
             input_ids=input_ids,
             attention_mask=attention_mask,
-            past_key_values=DynamicCache(),
+            past_key_values=DynamicCache(config=model.config),
             use_cache=True,
         )
         past_key_values_eager = res_eager.past_key_values
@@ -743,6 +730,7 @@ class CacheExportIntegrationTest(unittest.TestCase):
             self.assertTrue(torch.allclose(l1.values, l2.values, atol=1e-5))
 
     @unittest.skip("Runs on my machine locally, passed, no idea why it does not online")
+    @pytest.mark.torch_export_test
     def test_static_cache_exportability(self):
         """
         Tests that static cache works with `torch.export()`
@@ -761,7 +749,7 @@ class CacheExportIntegrationTest(unittest.TestCase):
         model = AutoModelForCausalLM.from_pretrained(
             model_id,
             device_map=device,
-            torch_dtype=dtype,
+            dtype=dtype,
             attn_implementation=attn_implementation,
             generation_config=GenerationConfig(
                 use_cache=True,
@@ -821,6 +809,7 @@ class CacheExportIntegrationTest(unittest.TestCase):
             strict=strict,
         )
 
+    @pytest.mark.torch_export_test
     def test_hybrid_cache_exportability(self):
         """
         Tests that static cache works with `torch.export()`
@@ -835,14 +824,29 @@ class CacheExportIntegrationTest(unittest.TestCase):
         model = AutoModelForCausalLM.from_pretrained(model_id)
         model.eval()
         self.assertEqual(model.config.use_cache, True)
-        self.assertEqual(model.config.cache_implementation, "hybrid")
 
-        # Export + HybridCache
+        # Export + hybrid StaticCache
         model.eval()
         max_batch_size = 1
         max_cache_len = 23
-        exportable_module = TorchExportableModuleForDecoderOnlyLM(model, max_batch_size, max_cache_len)
-        exported_program = exportable_module.export()
+        # Set generation config on the model for the hybrid cache model
+        from transformers.generation.configuration_utils import GenerationConfig
+
+        model.generation_config = GenerationConfig(
+            use_cache=True,
+            cache_implementation="static",
+            max_length=max_cache_len,
+            cache_config={
+                "batch_size": max_batch_size,
+                "max_cache_len": max_cache_len,
+                "device": model.device,
+            },
+        )
+        exportable_module = TorchExportableModuleForDecoderOnlyLM(model)
+        exported_program = exportable_module.export(
+            input_ids=torch.tensor([[1]], dtype=torch.long, device=model.device),
+            cache_position=torch.tensor([0], dtype=torch.long, device=model.device),
+        )
         n_g_key_caches = n_g_value_caches = 0
         for buffer_name, buffer in exported_program.named_buffers():
             if buffer_name.startswith("key_cache"):
@@ -883,12 +887,13 @@ class SyntheticCacheTest(unittest.TestCase):
             head_dim=1,
             hidden_size=1,
             sliding_window=self.window_size,
+            attention_chunk_size=self.window_size,
             layer_types=["full_attention"] * 1,  # Static cache by default
         )
 
     def test_static_cache_out_of_bounds(self):
         """Test StaticCache raises IndexError for out-of-bounds positions."""
-        static_cache = StaticCache(config=self.config, max_batch_size=1, max_cache_len=self.max_cache_len)
+        static_cache = StaticCache(config=self.config, max_cache_len=self.max_cache_len)
         pos_out_of_bounds = torch.tensor([self.max_cache_len])  # Position >= max_cache_len
 
         with self.assertRaises(IndexError):
@@ -910,7 +915,7 @@ class SyntheticCacheTest(unittest.TestCase):
         update pos 3:  [1.0, 2.0, 3.0, 4.0]
         """
         # Scenario 1: Fill up to near capacity
-        static_cache = StaticCache(config=self.config, max_batch_size=1, max_cache_len=self.max_cache_len)
+        static_cache = StaticCache(config=self.config, max_cache_len=self.max_cache_len)
         prefill = torch.tensor([1.0, 2.0, 0.0, 0.0])[None, None, :, None]
         static_cache.update(key_states=prefill, value_states=prefill, layer_idx=0, cache_kwargs=None)
         static_cache.update(
@@ -935,7 +940,7 @@ class SyntheticCacheTest(unittest.TestCase):
         )
 
     def test_sliding_window_cache(self):
-        """Test SlidingWindowCache with manually prefilled states and hardcoded assertions.
+        """Test fully sliding StaticCache with manually prefilled states and hardcoded assertions.
 
         Scenario 1: Update within window, no slide yet
         prefill:       [1.0, 2.0, 0.0, 0.0]
@@ -952,197 +957,60 @@ class SyntheticCacheTest(unittest.TestCase):
         # Scenario 1: Update within window, no slide yet
         config = copy.deepcopy(self.config)
         config.layer_types = ["sliding_attention"] * config.num_hidden_layers
-        sliding_cache = SlidingWindowCache(config=config, max_batch_size=1, max_cache_len=self.max_cache_len)
-        prefill = torch.tensor([1.0, 2.0, 0.0, 0.0])[None, None, :, None]
+        sliding_cache = StaticCache(config=config, max_cache_len=self.max_cache_len)
+        prefill = torch.tensor([1.0, 2.0])[None, None, :, None]
         sliding_cache.update(
             key_states=prefill,
             value_states=prefill,
             layer_idx=0,
-            cache_kwargs={"cache_position": torch.arange(4), "sliding_window": self.window_size},
+            cache_kwargs={"cache_position": torch.arange(2)},
         )
         sliding_cache.update(
-            key_states=torch.tensor(3.0)[None, None, None, None],
-            value_states=torch.tensor(3.0)[None, None, None, None],
-            layer_idx=0,
-            cache_kwargs={"cache_position": torch.tensor([2]), "sliding_window": self.window_size},
-        )
-        self.assertEqual(
-            sliding_cache.layers[0].keys[0, 0, :, 0].tolist(),
-            [1.0, 2.0, 3.0, 0.0],
-            "SlidingWindowCache Scenario 1 failed",
-        )
-
-        # Scenario 2: Update causing slide
-        sliding_cache = SlidingWindowCache(config=config, max_batch_size=1, max_cache_len=self.max_cache_len)
-        prefill = torch.tensor([1.0, 2.0, 3.0, 4.0])[None, None, :, None]
-        sliding_cache.update(
-            key_states=prefill,
-            value_states=prefill,
-            layer_idx=0,
-            cache_kwargs={"cache_position": torch.arange(4), "sliding_window": self.window_size},
-        )
-        sliding_cache.update(
-            key_states=torch.tensor(5.0)[None, None, None, None],
-            value_states=torch.tensor(5.0)[None, None, None, None],
-            layer_idx=0,
-            cache_kwargs={"cache_position": torch.tensor([4]), "sliding_window": self.window_size},
-        )
-        self.assertEqual(
-            sliding_cache.layers[0].keys[0, 0, :, 0].tolist(),
-            [2.0, 3.0, 4.0, 5.0],
-            "SlidingWindowCache Scenario 2 failed",
-        )
-
-        # Scenario 3: Long prompt handling
-        sliding_cache = SlidingWindowCache(config=config, max_batch_size=1, max_cache_len=self.max_cache_len)
-        long_prefill = torch.tensor([1.0, 2.0, 3.0, 4.0, 5.0, 6.0])[None, None, :, None]
-        sliding_cache.update(
-            key_states=long_prefill,
-            value_states=long_prefill,
-            layer_idx=0,
-            cache_kwargs={"cache_position": torch.arange(6), "sliding_window": self.window_size},
-        )
-        self.assertEqual(
-            sliding_cache.layers[0].keys[0, 0, :, 0].tolist(),
-            [3.0, 4.0, 5.0, 6.0],
-            "SlidingWindowCache Scenario 3 failed",
-        )
-
-    def test_hybrid_cache_static_mode(self):
-        """Test HybridCache with only 1 static layer.
-
-        Scenario 1: Static layer behavior
-        prefill:       [1.0, 2.0, 0.0, 0.0]
-        update pos 2:  [1.0, 2.0, 3.0, 0.0]
-
-        Scenario 2: Fill to capacity
-        update pos 3:  [1.0, 2.0, 3.0, 4.0]
-        """
-        config = copy.deepcopy(self.config)
-        config.layer_types = ["full_attention"] * config.num_hidden_layers
-
-        # Scenario 1
-        hybrid_cache_static_mode = HybridCache(config=config, max_batch_size=1, max_cache_len=self.max_cache_len)
-        prefill = torch.tensor([1.0, 2.0, 0.0, 0.0])[None, None, :, None]
-        hybrid_cache_static_mode.update(
-            key_states=prefill,
-            value_states=prefill,
-            layer_idx=0,
-            cache_kwargs={"cache_position": torch.arange(4)},
-        )
-        hybrid_cache_static_mode.update(
             key_states=torch.tensor(3.0)[None, None, None, None],
             value_states=torch.tensor(3.0)[None, None, None, None],
             layer_idx=0,
             cache_kwargs={"cache_position": torch.tensor([2])},
         )
         self.assertEqual(
-            hybrid_cache_static_mode.layers[0].keys[0, 0, :, 0].tolist(),
+            sliding_cache.layers[0].keys[0, 0, :, 0].tolist(),
             [1.0, 2.0, 3.0, 0.0],
-            "HybridCache Static Scenario 1 failed",
+            "Fully sliding StaticCache Scenario 1 failed",
         )
 
-        # Scenario 2
-        hybrid_cache_static_mode.update(
-            key_states=torch.tensor(4.0)[None, None, None, None],
-            value_states=torch.tensor(4.0)[None, None, None, None],
-            layer_idx=0,
-            cache_kwargs={"cache_position": torch.tensor([3])},
-        )
-        self.assertEqual(
-            hybrid_cache_static_mode.layers[0].keys[0, 0, :, 0].tolist(),
-            [1.0, 2.0, 3.0, 4.0],
-            "HybridCache Static Scenario 2 failed",
-        )
-
-    def test_hybrid_cache_sliding_mode(self):
-        """Test HybridCache in sliding mode with hardcoded assertions.
-
-        Scenario 1: Update within window, no slide yet
-        prefill:       [1.0, 2.0, 0.0, 0.0]
-        update pos 2:  [1.0, 2.0, 3.0, 0.0]
-
-        Scenario 2: Update causing first slide
-        prefill:       [1.0, 2.0, 3.0, 4.0]
-        update pos 4:  [2.0, 3.0, 4.0, 5.0] (shift happens as pos > window_size-1)
-
-        Scenario 3: Update causing subsequent slide
-        update pos 5:  [3.0, 4.0, 5.0, 6.0] (shift continues)
-
-        Scenario 4: Long prompt handling (prompt_len > window_size)
-        input:         [1.0, 2.0, 3.0, 4.0, 5.0, 6.0]
-        result:        [3.0, 4.0, 5.0, 6.0] (keeps last window_size tokens)
-        """
-        config = copy.deepcopy(self.config)
-        config.layer_types = ["sliding_attention"] * config.num_hidden_layers
-        # Scenario 1: Update within window, no slide yet
-        hybrid_cache = HybridCache(config=config, max_batch_size=1, max_cache_len=self.max_cache_len)
-        prefill = torch.tensor([1.0, 2.0, 0.0, 0.0])[None, None, :, None]
-        hybrid_cache.update(
-            key_states=prefill,
-            value_states=prefill,
-            layer_idx=0,
-            cache_kwargs={"cache_position": torch.arange(4), "sliding_window": self.window_size},
-        )
-        hybrid_cache.update(
-            key_states=torch.tensor(3.0)[None, None, None, None],
-            value_states=torch.tensor(3.0)[None, None, None, None],
-            layer_idx=0,
-            cache_kwargs={"cache_position": torch.tensor([2]), "sliding_window": self.window_size},
-        )
-        self.assertEqual(
-            hybrid_cache.layers[0].keys[0, 0, :, 0].tolist(),
-            [1.0, 2.0, 3.0, 0.0],
-            "HybridCache Sliding Scenario 1 failed",
-        )
-
-        # Scenario 2: Update causing first slide
-        hybrid_cache = HybridCache(config=config, max_batch_size=1, max_cache_len=self.max_cache_len)
+        # Scenario 2: Update causing slide
+        sliding_cache = StaticCache(config=config, max_cache_len=self.max_cache_len)
         prefill = torch.tensor([1.0, 2.0, 3.0, 4.0])[None, None, :, None]
-        hybrid_cache.update(
+        sliding_cache.update(
             key_states=prefill,
             value_states=prefill,
             layer_idx=0,
-            cache_kwargs={"cache_position": torch.arange(4), "sliding_window": self.window_size},
+            cache_kwargs={"cache_position": torch.arange(4)},
         )
-        hybrid_cache.update(
+        sliding_cache.update(
             key_states=torch.tensor(5.0)[None, None, None, None],
             value_states=torch.tensor(5.0)[None, None, None, None],
             layer_idx=0,
-            cache_kwargs={"cache_position": torch.tensor([4]), "sliding_window": self.window_size},
+            cache_kwargs={"cache_position": torch.tensor([4])},
         )
         self.assertEqual(
-            hybrid_cache.layers[0].keys[0, 0, :, 0].tolist(),
+            sliding_cache.layers[0].keys[0, 0, :, 0].tolist(),
             [2.0, 3.0, 4.0, 5.0],
-            "HybridCache Sliding Scenario 2 failed",
+            "Fully sliding StaticCache Scenario 2 failed",
         )
 
-        # Scenario 3: Update causing subsequent slide
-        hybrid_cache.update(
-            key_states=torch.tensor(6.0)[None, None, None, None],
-            value_states=torch.tensor(6.0)[None, None, None, None],
-            layer_idx=0,
-            cache_kwargs={"cache_position": torch.tensor([5]), "sliding_window": self.window_size},
-        )
-        self.assertEqual(
-            hybrid_cache.layers[0].keys[0, 0, :, 0].tolist(),
-            [3.0, 4.0, 5.0, 6.0],
-            "HybridCache Sliding Scenario 3 failed",
-        )
-
-        # Scenario 4: Long prompt handling
-        hybrid_cache = HybridCache(config=config, max_batch_size=1, max_cache_len=self.max_cache_len)
+        # Scenario 3: Long prompt handling
+        sliding_cache = StaticCache(config=config, max_cache_len=self.max_cache_len)
         long_prefill = torch.tensor([1.0, 2.0, 3.0, 4.0, 5.0, 6.0])[None, None, :, None]
-        hybrid_cache.update(
+        sliding_cache.update(
             key_states=long_prefill,
             value_states=long_prefill,
             layer_idx=0,
-            cache_kwargs={"cache_position": torch.arange(6), "sliding_window": self.window_size},
+            cache_kwargs={"cache_position": torch.arange(6)},
         )
         self.assertEqual(
-            hybrid_cache.layers[0].keys[0, 0, :, 0].tolist(),
+            sliding_cache.layers[0].keys[0, 0, :, 0].tolist(),
             [3.0, 4.0, 5.0, 6.0],
-            "HybridCache Sliding Scenario 4 failed",
+            "Fully sliding StaticCache Scenario 3 failed",
         )
 
     def test_dynamic_cache(self):
@@ -1188,9 +1056,31 @@ class SyntheticCacheTest(unittest.TestCase):
             "DynamicCache Scenario 2 layer 1 failed",
         )
 
+    def test_dynamic_cache_batch_select_indices(self):
+        """Select a subset of batches in-place using batch_select_indices."""
+        cache = DynamicCache()
+        # Shape: (batch=3, heads=1, seq_len=2, head_dim=1)
+        prefill = torch.tensor(
+            [
+                [[[1.0], [2.0]]],
+                [[[10.0], [20.0]]],
+                [[[100.0], [200.0]]],
+            ]
+        )
+        cache.update(prefill, prefill, 0)
+        self.assertEqual(cache.layers[0].keys.shape[0], 3)
+
+        # Keep batches 0 and 2
+        cache.batch_select_indices((0, 2))
+        self.assertEqual(cache.layers[0].keys.shape[0], 2)
+        self.assertEqual(
+            cache.layers[0].keys[:, 0, :, 0].tolist(),
+            [[1.0, 2.0], [100.0, 200.0]],
+        )
+
     def test_hybrid_cache(self):
         """
-        Test HybridCache with a mix of static and sliding layers,
+        Test hybrid StaticCache with a mix of static and sliding layers,
         with prefill size bigger than sliding window.
 
         prefill:
@@ -1206,7 +1096,7 @@ class SyntheticCacheTest(unittest.TestCase):
         config.num_hidden_layers = 2
         config.layer_types = ["full_attention", "sliding_attention"]
         config.sliding_window = 2
-        hybrid_cache = HybridCache(config=config, max_batch_size=1, max_cache_len=self.max_cache_len)
+        hybrid_cache = StaticCache(config=config, max_cache_len=self.max_cache_len)
 
         # Prefill both layers up to cache capacity
         prefill_static = torch.tensor([1.0, 2.0, 3.0])[None, None, :, None]
@@ -1287,7 +1177,7 @@ class SyntheticCacheTest(unittest.TestCase):
 
     def test_hybrid_chunked_cache(self):
         """
-        Test HybridChunkedCache with both static and sliding layers and special cases:
+        Test hybrid chunked StaticCache with both static and sliding layers and special cases:
             1. a pre-fill longer than the sliding window
             2. a single-token decoding step (normal generation)
             3. a multi-token decoding step after the window is already full
@@ -1308,9 +1198,10 @@ class SyntheticCacheTest(unittest.TestCase):
         config = copy.deepcopy(self.config)
         config.num_hidden_layers = 2
         config.layer_types = ["full_attention", "chunked_attention"]
-        config.sliding_window = 2
+        config.attention_chunk_size = 2
+        config.sliding_window = None
         max_cache_len = 4
-        chunked_cache = HybridChunkedCache(config=config, max_batch_size=1, max_cache_len=max_cache_len)
+        chunked_cache = StaticCache(config=config, max_cache_len=max_cache_len)
 
         # 1) PREFILL (3 tokens > sliding_window)
         prefill_static = torch.tensor([1.0, 2.0, 3.0])[None, None, :, None]
@@ -1388,8 +1279,9 @@ class SyntheticCacheTest(unittest.TestCase):
         config = copy.deepcopy(self.config)
         config.num_hidden_layers = 1
         config.layer_types = ["chunked_attention"]
-        config.sliding_window = 3
-        cache = HybridChunkedCache(config, max_batch_size=1, max_cache_len=3)
+        config.sliding_window = None
+        config.attention_chunk_size = 3
+        cache = StaticCache(config=config, max_cache_len=3)
 
         # Step 0 : multi-token prefill
         first_chunk = torch.tensor([10.0, 20.0])[None, None, :, None]  # L = 2
